@@ -57,7 +57,7 @@ static Obj IsOutputStream;
 */
 UInt OpenErrorOutput(TypOutputFile * output)
 {
-    /* Try to print the output to stream. Use *errout* as a fallback. */
+    // Try to print the output to stream. Use *errout* as a fallback.
     UInt ret = 0;
 
     if (ERROR_OUTPUT != NULL) {
@@ -152,6 +152,11 @@ static Obj FuncCURRENT_STATEMENT_LOCATION(Obj self, Obj context)
         return Fail;
     }
 
+    Obj filename = GET_FILENAME_BODY(body);
+    if (!filename) {
+        return Fail;
+    }
+
     Obj currLVars = SWITCH_TO_OLD_LVARS(context);
 
     Obj retlist = Fail;
@@ -159,7 +164,6 @@ static Obj FuncCURRENT_STATEMENT_LOCATION(Obj self, Obj context)
     if ((FIRST_STAT_TNUM <= type && type <= LAST_STAT_TNUM) ||
         (FIRST_EXPR_TNUM <= type && type <= LAST_EXPR_TNUM)) {
         Int line = LINE_STAT(call);
-        Obj filename = GET_FILENAME_BODY(body);
         retlist = NewPlistFromArgs(filename, INTOBJ_INT(line));
     }
     SWITCH_TO_OLD_LVARS(currLVars);
@@ -171,8 +175,8 @@ static Obj FuncPRINT_CURRENT_STATEMENT(Obj self, Obj stream, Obj context)
     if (IsBottomLVars(context))
         return 0;
 
-    /* HACK: we want to redirect output */
-    /* Try to print the output to stream. Use *errout* as a fallback. */
+    // HACK: we want to redirect output
+    // Try to print the output to stream. Use *errout* as a fallback.
     TypOutputFile output = { 0 };
     if ((IsStringConv(stream) &&
          !OpenOutput(&output, CONST_CSTR_STRING(stream), FALSE)) ||
@@ -192,6 +196,7 @@ static Obj FuncPRINT_CURRENT_STATEMENT(Obj self, Obj stream, Obj context)
         GAP_ASSERT(func);
         Stat call = STAT_LVARS(context);
         Obj  body = BODY_FUNC(func);
+        Obj  filename = GET_FILENAME_BODY(body);
         if (IsKernelFunction(func)) {
             PrintKernelFunction(func);
             Obj funcname = NAME_FUNC(func);
@@ -203,11 +208,10 @@ static Obj FuncPRINT_CURRENT_STATEMENT(Obj self, Obj stream, Obj context)
                  call > SIZE_BAG(body) - sizeof(StatHeader)) {
             Pr("<corrupted statement> ", 0, 0);
         }
-        else {
+        else if (filename) {
             Obj currLVars = SWITCH_TO_OLD_LVARS(context);
 
             Int type = TNUM_STAT(call);
-            Obj filename = GET_FILENAME_BODY(body);
             if (FIRST_STAT_TNUM <= type && type <= LAST_STAT_TNUM) {
                 PrintStat(call);
                 Pr(" at %g:%d", (Int)filename, LINE_STAT(call));
@@ -224,7 +228,7 @@ static Obj FuncPRINT_CURRENT_STATEMENT(Obj self, Obj stream, Obj context)
         rethrow = TRUE;
     }
 
-    /* HACK: close the output again */
+    // HACK: close the output again
     CloseOutput(&output);
 
     if (rethrow)
@@ -458,7 +462,7 @@ void ErrorReturnVoid(const Char * msg, Int arg1, Int arg2, const Char * msg2)
     Obj LateMsg;
     LateMsg = MakeString(msg2);
     CallErrorInner(msg, arg1, arg2, 0, 1, 0, LateMsg, 1);
-    /*    ErrorMode( msg, arg1, arg2, (Obj)0, msg2, 'x' ); */
+    // ErrorMode( msg, arg1, arg2, (Obj)0, msg2, 'x' );
 }
 
 /****************************************************************************
