@@ -106,7 +106,7 @@ static UInt Time;
 **
 *V  MemoryAllocated . . . . . . . . . . . global variable  'memory_allocated'
 **
-**  'MemoryAllocated' is the global variable 'memory_allocated', 
+**  'MemoryAllocated' is the global variable 'memory_allocated',
 **  which is automatically assigned the amount of memory allocated while
 **  executing the last command.
 */
@@ -136,7 +136,7 @@ void ViewObjHandler ( Obj obj )
   // save some values in case view runs into error
   volatile Bag  currLVars   = STATE(CurrLVars);
 
-  /* if non-zero use this function, otherwise use `PrintObj'             */
+  // if non-zero use this function, otherwise use `PrintObj'
   GAP_TRY {
     Obj func = ValAutoGVar(ViewObjGVar);
     if ( func != 0 && TNUM_OBJ(func) == T_FUNCTION ) {
@@ -241,19 +241,19 @@ static Obj FuncSHELL(Obj self,
         UInt  time = 0;
         UInt8 mem = 0;
 
-        /* start the stopwatch                                             */
+        // start the stopwatch
         if (breakLoop == False) {
             time = SyTime();
             mem = SizeAllBags;
         }
 
-        /* read and evaluate one command                                   */
+        // read and evaluate one command
         SetPrompt(CONST_CSTR_STRING(prompt));
         SetPrintObjState(0);
         ResetOutputIndent();
         SetRecursionDepth(0);
 
-        /* here is a hook: */
+        // here is a hook:
         if (preCommandHook) {
             Call0ArgsInNewReader(preCommandHook);
             // Recover from a potential break loop:
@@ -293,7 +293,7 @@ static Obj FuncSHELL(Obj self,
             break;
         }
 
-        /* handle ordinary command                                         */
+        // handle ordinary command
         if (status == STATUS_END && evalResult != 0) {
             UpdateLast(evalResult);
             if (!dualSemicolon) {
@@ -301,7 +301,7 @@ static Obj FuncSHELL(Obj self,
             }
         }
 
-        /* handle return-value or return-void command                      */
+        // handle return-value or return-void command
         else if (status == STATUS_RETURN && evalResult != 0) {
             if (canReturnObj == True)
                 break;
@@ -315,12 +315,12 @@ static Obj FuncSHELL(Obj self,
             Pr("'return' cannot be used in this read-eval-print loop\n", 0,
                0);
         }
-        /* handle quit command or <end-of-file>                            */
+        // handle quit command or <end-of-file>
         else if (status == STATUS_EOF || status == STATUS_QUIT) {
             break;
         }
 
-        /* stop the stopwatch                                          */
+        // stop the stopwatch
         if (breakLoop == False) {
             UpdateTime(time);
             AssGVarWithoutReadOnlyCheck(MemoryAllocated,
@@ -389,15 +389,15 @@ static Obj FuncSHELL(Obj self,
 
 int realmain( int argc, char * argv[] )
 {
-  UInt                type;                   /* result of compile       */
-  Obj                 func;                   /* function (compiler)     */
-  Int4                crc;                    /* crc of file to compile  */
+  UInt                type;                   // result of compile
+  Obj                 func;                   // function (compiler)
+  Int4                crc;                    // crc of file to compile
 
-  /* initialize everything and read init.g which runs the GAP session */
+  // initialize everything and read init.g which runs the GAP session
   InitializeGap( &argc, argv, 1 );
   if (!STATE(UserHasQUIT)) {         /* maybe the user QUIT from the initial
                                    read of init.g  somehow*/
-    /* maybe compile in which case init.g got skipped */
+    // maybe compile in which case init.g got skipped
     if ( SyCompilePlease ) {
       TypInputFile input;
       if ( ! OpenInput(&input, SyCompileInput) ) {
@@ -420,20 +420,6 @@ int realmain( int argc, char * argv[] )
   return SystemErrorCode;
 }
 
-#if !defined(COMPILECYGWINDLL)
-int main ( int argc, char * argv[] )
-{
-  InstallBacktraceHandlers();
-
-#ifdef HPCGAP
-  RunThreadedMain(realmain, argc, argv);
-  return 0;
-#else
-  return realmain(argc, argv);
-#endif
-}
-
-#endif
 
 /****************************************************************************
 **
@@ -488,10 +474,10 @@ static Obj FuncRETURN_NOTHING(Obj self, Obj arg)
 */
 static Obj FuncSizeScreen(Obj self, Obj args)
 {
-  Obj                 size;           /* argument and result list        */
-  Obj                 elm;            /* one entry from size             */
-  UInt                len;            /* length of lines on the screen   */
-  UInt                nr;             /* number of lines on the screen   */
+  Obj                 size;           // argument and result list
+  Obj                 elm;            // one entry from size
+  UInt                len;            // length of lines on the screen
+  UInt                nr;             // number of lines on the screen
 
   RequireSmallList(SELF_NAME, args);
   if (1 < LEN_LIST(args)) {
@@ -499,12 +485,12 @@ static Obj FuncSizeScreen(Obj self, Obj args)
                    LEN_LIST(args), 0);
   }
 
-  /* get the arguments                                                   */
+  // get the arguments
   if ( LEN_LIST(args) == 0 ) {
     size = NEW_PLIST( T_PLIST, 0 );
   }
 
-  /* otherwise check the argument                                        */
+  // otherwise check the argument
   else {
     size = ELM_LIST( args, 1 );
     if (!IS_SMALL_LIST(size) || 2 < LEN_LIST(size)) {
@@ -513,7 +499,7 @@ static Obj FuncSizeScreen(Obj self, Obj args)
     }
   }
 
-  /* extract the length                                                  */
+  // extract the length
   if ( LEN_LIST(size) < 1 || ELM0_LIST(size,1) == 0 ) {
     len = 0;
   }
@@ -524,7 +510,7 @@ static Obj FuncSizeScreen(Obj self, Obj args)
     if ( MAXLENOUTPUTLINE < len )  len = MAXLENOUTPUTLINE;
   }
 
-  /* extract the number                                                  */
+  // extract the number
   elm = ELM0_LIST(size, 2);
   if ( elm == 0 ) {
     nr = 0;
@@ -534,7 +520,7 @@ static Obj FuncSizeScreen(Obj self, Obj args)
     if ( nr < 10 )  nr = 10;
   }
 
-  /* set length and number                                               */
+  // set length and number
   if (len != 0)
     {
       SyNrCols = len;
@@ -546,7 +532,7 @@ static Obj FuncSizeScreen(Obj self, Obj args)
       SyNrRowsLocked = 1;
     }
 
-  /* make and return the size of the screen                              */
+  // make and return the size of the screen
   size = NEW_PLIST( T_PLIST, 2 );
   PushPlist(size, ObjInt_UInt(SyNrCols));
   PushPlist(size, ObjInt_UInt(SyNrRows));
@@ -581,7 +567,7 @@ static Obj FuncWindowCmd(Obj self, Obj args)
         ErrorMayQuit("WindowCmd: <cmd> must be a string of length 3", 0, 0);
     }
 
-  /* compute size needed to store argument string                        */
+  // compute size needed to store argument string
   len = 13;
   for ( i = 2;  i <= LEN_LIST(args);  i++ )
     {
@@ -601,14 +587,14 @@ static Obj FuncWindowCmd(Obj self, Obj args)
     ResizeBag( WindowCmdString, 2*len+1 );
   }
 
-  /* convert <args> into an argument string                              */
+  // convert <args> into an argument string
   ptr  = (Char*) CSTR_STRING(WindowCmdString);
 
-  /* first the command name                                              */
+  // first the command name
   memcpy( ptr, CONST_CSTR_STRING( ELM_LIST(args,1) ), 3 + 1 );
   ptr += 3;
 
-  /* and now the arguments                                               */
+  // and now the arguments
   for ( i = 2;  i <= LEN_LIST(args);  i++ )
     {
       tmp = ELM_LIST(args,i);
@@ -636,12 +622,12 @@ static Obj FuncWindowCmd(Obj self, Obj args)
     }
   *ptr = 0;
 
-  /* now call the window front end with the argument string              */
+  // now call the window front end with the argument string
   qtr = CONST_CSTR_STRING(WindowCmdString);
   inptr = SyWinCmd( qtr, strlen(qtr) );
   len = strlen(inptr);
 
-  /* now convert result back into a list                                 */
+  // now convert result back into a list
   list = NEW_PLIST( T_PLIST, 11 );
   i = 1;
   while ( 0 < len ) {
@@ -658,7 +644,7 @@ static Obj FuncWindowCmd(Obj self, Obj args)
       inptr++;
       for ( n=0,m=1;  '0' <= *inptr && *inptr <= '9';  inptr++,m *= 10,len-- )
         n += (*inptr-'0') * m;
-      inptr++; /* ignore the '+' */
+      inptr++; // ignore the '+'
       tmp = MakeImmStringWithLen(inptr, n);
       inptr += n;
       len -= n+2;
@@ -670,7 +656,7 @@ static Obj FuncWindowCmd(Obj self, Obj args)
     i++;
   }
 
-  /* if the first entry is one signal an error */
+  // if the first entry is one signal an error
   if ( ELM_LIST(list,1) == INTOBJ_INT(1) ) {
       tmp = MakeString("window system: ");
       SET_ELM_PLIST(list, 1, tmp);
@@ -707,10 +693,10 @@ static Obj FuncGASMAN(Obj self, Obj args)
             0, 0);
     }
 
-    /* loop over the arguments                                             */
+    // loop over the arguments
     for ( UInt i = 1; i <= LEN_LIST(args); i++ ) {
 
-        /* evaluate and check the command                                  */
+        // evaluate and check the command
         Obj cmd = ELM_PLIST( args, i );
         RequireStringRep(SELF_NAME, cmd);
 
@@ -732,7 +718,7 @@ static Obj FuncGASMAN(Obj self, Obj args)
 
 #else
 
-        /* if request display the statistics                               */
+        // if request display the statistics
         else if (streq(CONST_CSTR_STRING(cmd), "display")) {
 #ifdef COUNT_BAGS
             Pr("%40s ", (Int)"type", 0);
@@ -753,14 +739,14 @@ static Obj FuncGASMAN(Obj self, Obj args)
 #endif
         }
 
-        /* if request give a short display of the statistics                */
+        // if request give a short display of the statistics
         else if (streq(CONST_CSTR_STRING(cmd), "displayshort")) {
 #ifdef COUNT_BAGS
             Pr("%40s ", (Int)"type", 0);
             Pr( "%8s %8s ",  (Int)"alive", (Int)"kbyte" );
             Pr( "%8s %8s\n",  (Int)"total", (Int)"kbyte" );
             for ( UInt k = 0; k < NUM_TYPES; k++ ) {
-                if ( TNAM_TNUM(k) != 0 && 
+                if ( TNAM_TNUM(k) != 0 &&
                      (InfoBags[k].nrLive != 0 ||
                       InfoBags[k].sizeLive != 0 ||
                       InfoBags[k].nrAll != 0 ||
@@ -778,7 +764,7 @@ static Obj FuncGASMAN(Obj self, Obj args)
 #endif
         }
 
-        /* if request display the statistics                               */
+        // if request display the statistics
         else if (streq(CONST_CSTR_STRING(cmd), "clear")) {
 #ifdef COUNT_BAGS
             for ( UInt k = 0; k < NUM_TYPES; k++ ) {
@@ -793,7 +779,7 @@ static Obj FuncGASMAN(Obj self, Obj args)
 #endif
         }
 
-        /* or display information about global bags                        */
+        // or display information about global bags
         else if (streq(CONST_CSTR_STRING(cmd), "global")) {
             for ( i = 0;  i < GlobalBags.nr;  i++ ) {
                 Bag bag = *(GlobalBags.addr[i]);
@@ -807,12 +793,12 @@ static Obj FuncGASMAN(Obj self, Obj args)
             }
         }
 
-        /* or finally toggle Gasman messages                               */
+        // or finally toggle Gasman messages
         else if (streq(CONST_CSTR_STRING(cmd), "message")) {
             SyMsgsFlagBags = (SyMsgsFlagBags + 1) % 3;
         }
 
-        /* otherwise complain                                              */
+        // otherwise complain
         else {
             ErrorMayQuit("GASMAN: <cmd> must be "
                          "\"display\" or \"clear\" or \"global\" or "
@@ -844,9 +830,9 @@ static Obj FuncGASMAN_STATS(Obj self)
           x = SyGasmanNumbers[i-1][j];
           SET_ELM_PLIST(row, j, ObjInt_Int(x));
         }
-      SET_ELM_PLIST(row, 9, INTOBJ_INT(SyGasmanNumbers[i-1][0]));       
+      SET_ELM_PLIST(row, 9, INTOBJ_INT(SyGasmanNumbers[i-1][0]));
     }
-  return res;      
+  return res;
 }
 
 static Obj FuncGASMAN_MESSAGE_STATUS(Obj self)
@@ -1020,13 +1006,13 @@ static Obj FuncQuitGap(Obj self, Obj args)
   if ( LEN_LIST(args) == 0 ) {
     SystemErrorCode = 0;
   }
-  else if ( LEN_LIST(args) != 1 
+  else if ( LEN_LIST(args) != 1
             || !SetExitValue(ELM_PLIST(args, 1) ) ) {
     ErrorQuit( "usage: QuitGap( [ <return value> ] )", 0, 0);
   }
   STATE(UserHasQUIT) = TRUE;
   GAP_THROW();
-  return (Obj)0; 
+  return (Obj)0;
 }
 
 /****************************************************************************
@@ -1041,7 +1027,7 @@ static Obj FuncForceQuitGap(Obj self, Obj args)
   {
     SyExit(SystemErrorCode);
   }
-  else if ( LEN_LIST(args) != 1 
+  else if ( LEN_LIST(args) != 1
             || !SetExitValue(ELM_PLIST(args, 1) ) ) {
     ErrorQuit( "usage: ForceQuitGap( [ <return value> ] )", 0, 0);
   }
@@ -1062,7 +1048,7 @@ static Obj FuncSHOULD_QUIT_ON_BREAK(Obj self)
 /****************************************************************************
 **
 *F  KERNEL_INFO() ......................record of information from the kernel
-** 
+**
 ** The general idea is to put all kernel-specific info in here, and clean up
 ** the assortment of global variables previously used
 */
@@ -1104,7 +1090,7 @@ static Obj FuncKERNEL_INFO(Obj self)
         }
         Obj name = MakeStringWithLen(environ[i], p - environ[i]);
         r = RNamName(CONST_CSTR_STRING(name));
-        p++; /* Move pointer behind = character */
+        p++; // Move pointer behind = character
         AssPRec(tmp, r, MakeImmString(p));
     }
     AssPRec(res, RNamName("ENVIRONMENT"), tmp);
@@ -1223,7 +1209,7 @@ void UpdateTime(UInt startTime)
 
 // UPDATE_STAT lets code assign the special variables which GAP
 // automatically sets in interactive sessions. This is for demonstration
-// code which wants to look like iteractive usage of GAP. Using this
+// code which wants to look like interactive usage of GAP. Using this
 // function will not stop GAP automatically changing these variables as
 // usual.
 static Obj FuncUPDATE_STAT(Obj self, Obj name, Obj newStat)
@@ -1329,13 +1315,13 @@ static StructGVarFunc GVarFuncs[] = {
 static Int InitKernel (
     StructInitInfo *    module )
 {
-    /* list of exit functions                                              */
+    // list of exit functions
     InitGlobalBag( &WindowCmdString, "src/gap.c:WindowCmdString" );
 
-    /* init filters and functions                                          */
+    // init filters and functions
     InitHdlrFuncsFromTable( GVarFuncs );
 
-    /* establish Fopy of ViewObj                                           */
+    // establish Fopy of ViewObj
     ImportFuncFromLibrary(  "ViewObj", 0 );
     ImportFuncFromLibrary(  "Error", &Error );
     return 0;
@@ -1349,10 +1335,10 @@ static Int InitKernel (
 static Int PostRestore (
     StructInitInfo *    module )
 {
-    /* construct the `ViewObj' variable                                    */
+    // construct the `ViewObj' variable
     ViewObjGVar = GVarName( "ViewObj" );
 
-    /* construct the last and time variables                               */
+    // construct the last and time variables
     Last              = GVarName( "last"  );
     Last2             = GVarName( "last2" );
     Last3             = GVarName( "last3" );
@@ -1372,10 +1358,10 @@ static Int PostRestore (
 static Int InitLibrary (
     StructInitInfo *    module )
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitGVarFuncsFromTable( GVarFuncs );
 
-    /* create windows command buffer                                       */
+    // create windows command buffer
     WindowCmdString = NEW_STRING( 1000 );
 
 #ifdef HPCGAP
@@ -1422,7 +1408,7 @@ StructInitInfo * InitInfoGap ( void )
 
 /****************************************************************************
 **
-*F  InitializeGap() . . . . . . . . . . . . . . . . . . . . . . intialize GAP
+*F  InitializeGap() . . . . . . . . . . . . . . . . . . . . .  initialize GAP
 **
 **  Each module  (builtin  or compiled) exports  a structure  which  contains
 **  information about the name, version, crc, init function, save and restore
@@ -1450,10 +1436,10 @@ void InitializeGap (
     char *              argv [],
     UInt                handleSignals )
 {
-    /* initialize the basic system and gasman                              */
+    // initialize the basic system and gasman
     InitSystem( *pargc, argv, handleSignals );
 
-    /* Initialise memory  -- have to do this here to make sure we are at top of C stack */
+    // Initialise memory  -- have to do this here to make sure we are at top of C stack
     InitBags(
 #if defined(USE_GASMAN)
         SyStorMin,
@@ -1509,7 +1495,7 @@ void InitializeGap (
         LoadWorkspace(SyRestoring);
         SyRestoring = NULL;
 
-        /* Call POST_RESTORE which is a GAP function that now takes control, 
+        /* Call POST_RESTORE which is a GAP function that now takes control,
            calls the post restore functions and then runs a GAP session */
         if (POST_RESTORE != 0 && IS_FUNC(POST_RESTORE)) {
           Call0ArgsInNewReader(POST_RESTORE);
@@ -1519,7 +1505,7 @@ void InitializeGap (
     }
 #endif // GAP_ENABLE_SAVELOAD
 
-    /* otherwise call library initialisation                               */
+    // otherwise call library initialisation
 #ifdef USE_GASMAN
     CheckAllHandlers();
 #endif
@@ -1528,21 +1514,19 @@ void InitializeGap (
     ModulesInitLibrary();
     ModulesInitModuleState();
 
-    /* check initialisation                                                */
+    // check initialisation
     ModulesCheckInit();
 
-    /* read the init files      
-       this now actually runs the GAP session, we only get 
-       past here when we're about to exit. 
+    /* read the init files
+       this now actually runs the GAP session, we only get
+       past here when we're about to exit.
                                            */
     if ( SyLoadSystemInitFile ) {
       GAP_TRY {
         if ( READ_GAP_ROOT("lib/init.g") == 0 ) {
-                Pr( "gap: hmm, I cannot find 'lib/init.g' maybe",
-                    0, 0);
-                Pr( " use option '-l <gaproot>'?\n If you ran the GAP"
-                    " binary directly, try running the 'gap.sh' or 'gap.bat'"
-                    " script instead.", 0, 0);
+                Pr( "gap: hmm, I cannot find 'lib/init.g' maybe"
+                    " use option '-l <gaproot>'?\n", 0, 0);
+                SystemErrorCode = 1;
             }
       }
       GAP_CATCH {
