@@ -24,15 +24,12 @@
 #include <string.h>
 
 
-/* List of active hooks */
-struct InterpreterHooks * activeHooks[HookCount];
+// List of active hooks
+struct InterpreterHooks * activeHooks[MAX_HOOK_COUNT];
 
-/* Number of active hooks */
+// Number of active hooks
 static Int HookActiveCount;
 
-/* If a print hook is current active */
-static Int PrintHookActive;
-
 /****************************************************************************
 **
 ** Store the true values of each function we wrap for hooking. These always
@@ -44,9 +41,6 @@ ExecStatFunc OriginalExecStatFuncsForHook[256];
 EvalExprFunc OriginalEvalExprFuncsForHook[256];
 EvalBoolFunc OriginalEvalBoolFuncsForHook[256];
 
-PrintStatFunc OriginalPrintStatFuncsForHook[256];
-PrintExprFunc OriginalPrintExprFuncsForHook[256];
-
 /****************************************************************************
 **
 ** These functions install implementations of eval/expr functions,
@@ -83,26 +77,6 @@ void InstallExecStatFunc(Int pos, ExecStatFunc f)
     HashUnlock(&activeHooks);
 }
 
-void InstallPrintStatFunc(Int pos, PrintStatFunc f)
-{
-    OriginalPrintStatFuncsForHook[pos] = f;
-    HashLock(&activeHooks);
-    if(!PrintHookActive) {
-        PrintStatFuncs[pos] = f;
-    }
-    HashUnlock(&activeHooks);
-}
-
-void InstallPrintExprFunc(Int pos, PrintExprFunc f)
-{
-    OriginalPrintExprFuncsForHook[pos] = f;
-    HashLock(&activeHooks);
-    if(!PrintHookActive) {
-        PrintExprFuncs[pos] = f;
-    }
-    HashUnlock(&activeHooks);
-}
-
 static ExecStatus ProfileExecStatPassthrough(Stat stat)
 {
     GAP_HOOK_LOOP(visitStat, stat);
@@ -117,8 +91,8 @@ static Obj ProfileEvalExprPassthrough(Expr stat)
 
 static Obj ProfileEvalBoolPassthrough(Expr stat)
 {
-    /* There are two cases we must pass through without touching */
-    /* From TNUM_EXPR */
+    // There are two cases we must pass through without touching
+    // From TNUM_EXPR
     if (IS_REF_LVAR(stat)) {
         return OriginalEvalBoolFuncsForHook[EXPR_REF_LVAR](stat);
     }
@@ -135,19 +109,19 @@ static Obj ProfileEvalBoolPassthrough(Expr stat)
 **
 */
 
-Int ActivateHooks(struct InterpreterHooks * hook)
+void ActivateHooks(struct InterpreterHooks * hook)
 {
     Int i;
 
-    if (HookActiveCount == HookCount) {
-        return 0;
+    if (HookActiveCount == MAX_HOOK_COUNT) {
+        return;
     }
 
     HashLock(&activeHooks);
-    for (i = 0; i < HookCount; ++i) {
+    for (i = 0; i < MAX_HOOK_COUNT; ++i) {
         if (activeHooks[i] == hook) {
             HashUnlock(&activeHooks);
-            return 0;
+            return;
         }
     }
 
@@ -157,24 +131,20 @@ Int ActivateHooks(struct InterpreterHooks * hook)
         EvalBoolFuncs[i] = ProfileEvalBoolPassthrough;
     }
 
-    for (i = 0; i < HookCount; ++i) {
+    for (i = 0; i < MAX_HOOK_COUNT; ++i) {
         if (!activeHooks[i]) {
             activeHooks[i] = hook;
             HookActiveCount++;
-            HashUnlock(&activeHooks);
-            return 1;
+            break;
         }
     }
     HashUnlock(&activeHooks);
-    return 0;
 }
 
-Int DeactivateHooks(struct InterpreterHooks * hook)
+void DeactivateHooks(struct InterpreterHooks * hook)
 {
-    Int i;
-
     HashLock(&activeHooks);
-    for (i = 0; i < HookCount; ++i) {
+    for (int i = 0; i < MAX_HOOK_COUNT; ++i) {
         if (activeHooks[i] == hook) {
             activeHooks[i] = 0;
             HookActiveCount--;
@@ -188,35 +158,6 @@ Int DeactivateHooks(struct InterpreterHooks * hook)
     }
 
     HashUnlock(&activeHooks);
-    return 1;
-}
-
-void ActivatePrintHooks(struct PrintHooks * hook)
-{
-    Int i;
-
-    if (PrintHookActive) {
-        return;
-    }
-    PrintHookActive = 1;
-    for (i = 0; i < ARRAY_SIZE(ExecStatFuncs); i++) {
-        if (hook->printStatPassthrough) {
-            PrintStatFuncs[i] = hook->printStatPassthrough;
-        }
-        if (hook->printExprPassthrough) {
-            PrintExprFuncs[i] = hook->printExprPassthrough;
-        }
-    }
-}
-
-void DeactivatePrintHooks(struct PrintHooks * hook)
-{
-    if (!PrintHookActive) {
-        return;
-    }
-    PrintHookActive = 0;
-    memcpy(PrintStatFuncs, OriginalPrintStatFuncsForHook, sizeof(PrintStatFuncs));
-    memcpy(PrintExprFuncs, OriginalPrintExprFuncsForHook, sizeof(PrintExprFuncs));
 }
 
 /****************************************************************************
@@ -239,7 +180,7 @@ static StructGVarFunc GVarFuncs[] = {
 */
 static Int InitLibrary(StructInitInfo * module)
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitGVarFuncsFromTable(GVarFuncs);
 
     return 0;
