@@ -2536,11 +2536,11 @@ static StructGVarFunc GVarFuncs[] = {
     GVAR_FUNC_1ARGS(SyncRead, syncvar),
     GVAR_FUNC_1ARGS(SyncIsBound, syncvar),
     GVAR_FUNC_1ARGS(IS_LOCKED, obj),
-    GVAR_FUNC_XARGS(LOCK, -1, "obj, ..."),
-    GVAR_FUNC_XARGS(DO_LOCK, -1, "obj, ..."),
+    GVAR_FUNC_XARGS(LOCK, -1, "obj"),
+    GVAR_FUNC_XARGS(DO_LOCK, -1, "obj"),
     GVAR_FUNC_1ARGS(WRITE_LOCK, obj),
     GVAR_FUNC_1ARGS(READ_LOCK, obj),
-    GVAR_FUNC_XARGS(TRYLOCK, -1, "obj, ..."),
+    GVAR_FUNC_XARGS(TRYLOCK, -1, "obj"),
     GVAR_FUNC_1ARGS(UNLOCK, sp),
     GVAR_FUNC_0ARGS(CURRENT_LOCKS),
     GVAR_FUNC_1ARGS(REFINE_TYPE, obj),
