@@ -44,9 +44,9 @@
 **  Returns a string that can be used as data structure of a new MT random
 **  number generator. <initstr> can be an arbitrary string as seed.
 */
-#define MATRIX_A 0x9908b0dfUL   /* constant vector a */
-#define UPPER_MASK 0x80000000UL /* most significant w-r bits */
-#define LOWER_MASK 0x7fffffffUL /* least significant r bits */
+#define MATRIX_A 0x9908b0dfUL   // constant vector a
+#define UPPER_MASK 0x80000000UL // most significant w-r bits
+#define LOWER_MASK 0x7fffffffUL // least significant r bits
 
 static void initGRMT(UInt4 * mt, UInt4 s)
 {
@@ -57,7 +57,7 @@ static void initGRMT(UInt4 * mt, UInt4 s)
             (1812433253UL * (mt[mti-1] ^ (mt[mti-1] >> 30)) + mti);
         mt[mti] &= 0xffffffffUL;
     }
-    /* store mti as last entry of mt[] */
+    // store mti as last entry of mt[]
     mt[624] = mti;
 }
 
@@ -70,7 +70,7 @@ static inline UChar checkedReadChar(const UChar * s, UInt4 pos, UInt4 len)
         return 0;
 }
 
-/* to read a seed string independently of endianness */
+// to read a seed string independently of endianness
 static inline UInt4 uint4frombytes(const UChar * s, UInt4 pos, UInt4 len)
 {
   UInt4 res;
@@ -90,7 +90,7 @@ static Obj FuncInitRandomMT(Obj self, Obj initstr)
   const UChar *init_key;
   UInt4 *mt, key_length, byte_key_length, i, j, k, N = 624;
 
-  /* check the seed, given as string */
+  // check the seed, given as string
   RequireStringRep(SELF_NAME, initstr);
 
   /* store array of 624 UInt4 and one UInt4 as counter "mti" and an
@@ -98,10 +98,10 @@ static Obj FuncInitRandomMT(Obj self, Obj initstr)
   str = NEW_STRING(4*626);
   SET_LEN_STRING(str, 4*626);
   mt = (UInt4 *)(ADDR_OBJ(str) + 1);
-  /* here the counter mti is set to 624 */
+  // here the counter mti is set to 624
   initGRMT(mt, 19650218UL);
   i=1; j=0;
-  /* Do not set these up until all garbage collection is done   */
+  // Do not set these up until all garbage collection is done
   init_key = CONST_CHARS_STRING(initstr);
   byte_key_length = GET_LEN_STRING(initstr);
   key_length = byte_key_length / 4;
@@ -121,7 +121,7 @@ static Obj FuncInitRandomMT(Obj self, Obj initstr)
       if (i>=N) { mt[0] = mt[N-1]; i=1; }
   }
   mt[0] = 0x80000000UL;
-  /* gives string "1234" in little endian as marker */
+  // gives string "1234" in little endian as marker
   mt[625] = 875770417UL;
   return str;
 }
@@ -158,7 +158,7 @@ UInt4 nextrandMT_int32(UInt4* mt)
     y = mt[mti++];
     mt[624] = mti;
 
-    /* Tempering */
+    // Tempering
     y ^= (y >> 11);
     y ^= (y << 7) & 0x9d2c5680UL;
     y ^= (y << 15) & 0xefc60000UL;
@@ -181,7 +181,7 @@ UInt4 nextrandMT_int32(UInt4* mt)
 // MurmurHash3 was written by Austin Appleby, and is placed in the public
 // domain. The author hereby disclaims copyright to this source code.
 
-/* Minor modifications to get it to compile in C rather than C++ and 
+/* Minor modifications to get it to compile in C rather than C++ and
 integrate with GAP  SL*/
 
 
@@ -247,9 +247,9 @@ void MurmurHash3_x86_32 ( const void * key, int len,
     k1 *= c1;
     k1 = ROTL32(k1,15);
     k1 *= c2;
-    
+
     h1 ^= k1;
-    h1 = ROTL32(h1,13); 
+    h1 = ROTL32(h1,13);
     h1 = h1*5+0xe6546b64;
   }
 
@@ -276,7 +276,7 @@ void MurmurHash3_x86_32 ( const void * key, int len,
   h1 = fmix4(h1);
 
   *(uint32_t*)out = h1;
-} 
+}
 
 #else
 
@@ -298,8 +298,8 @@ static inline uint64_t rotl64 ( uint64_t x, int8_t r )
 // Block read - if your platform needs to do endian-swapping or can only
 // handle aligned reads, do the conversion here
 //
-// The pointer p may not be aligned, which means that directly reading it can 
-// incur a major performance penalty or even trigger a segfault on certain 
+// The pointer p may not be aligned, which means that directly reading it can
+// incur a major performance penalty or even trigger a segfault on certain
 // architectures (e.g. ARM, SPARC). Thus we use memcpy here, with the implicit
 // hope that on archs which don't need this, the compiler will optimize it back
 // into a direct copy (verified to happen with GCC and clang on x86_64)
@@ -444,7 +444,7 @@ FuncHASHKEY_BAG(Obj self, Obj obj, Obj seed, Obj offset, Obj maxlen)
     ErrorMayQuit("HASHKEY_BAG: <obj> must not be an FFE", 0, 0);
   }
 
-  /* check the arguments                                                 */
+  // check the arguments
   Int s = GetSmallInt(SELF_NAME, seed);
 
   Int offs = GetSmallInt(SELF_NAME, offset);
@@ -454,7 +454,7 @@ FuncHASHKEY_BAG(Obj self, Obj obj, Obj seed, Obj offset, Obj maxlen)
                    0, 0);
   }
 
-  /* maximal number of bytes to read */
+  // maximal number of bytes to read
   Int imaxlen = GetSmallInt(SELF_NAME, maxlen);
 
   n=SIZE_OBJ(obj)-offs;
@@ -647,8 +647,8 @@ static Obj FuncMAKE_BITFIELDS(Obj self, Obj widths)
     Obj nameGetter = MakeImmString("<field getter>");
     Obj nameBSetter = MakeImmString("<boolean field setter>");
     Obj nameBGetter = MakeImmString("<boolean field getter>");
-    Obj dataArgs = ArgStringToList("data");
-    Obj dataValArgs = ArgStringToList("data, val");
+    Obj dataArgs = NewPlistFromArgs(MakeImmString("data"));
+    Obj dataValArgs = NewPlistFromArgs(MakeImmString("data"), MakeImmString("val"));
 
     Obj  setters = NEW_PLIST_IMM(T_PLIST_DENSE, nfields);
     Obj  getters = NEW_PLIST_IMM(T_PLIST_DENSE, nfields);
@@ -740,7 +740,7 @@ static Int InitKernel (
     InitHandlerFunc(DoBooleanFieldSetter, "boolean-field-setter");
     InitHandlerFunc(DoBooleanFieldGetter, "boolean-field-getter");
 
-    /* init filters and functions                                          */
+    // init filters and functions
     InitHdlrFuncsFromTable( GVarFuncs );
 
     return 0;
@@ -754,7 +754,7 @@ static Int InitKernel (
 static Int InitLibrary (
     StructInitInfo *    module )
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitGVarFuncsFromTable( GVarFuncs );
 
     return 0;
