@@ -116,7 +116,7 @@ struct TypOutputFile {
     BOOL format;
     Int  indent;
 
-    /* each hint is a triple (position, value, indent) */
+    // each hint is a triple (position, value, indent)
     Int hints[3 * MAXHINTS + 1];
 };
 
@@ -272,17 +272,6 @@ UInt OpenInputLogStream(Obj stream);
 */
 UInt CloseInputLog(void);
 
-/****************************************************************************
- **
- *V  Prompt  . . . . . . . . . . . . . . . . . . . . . . prompt to be printed
- **
- **  'Prompt' holds the string that is to be printed if a  new  line  is read
- **  from the interactive files '*stdin*' or '*errin*'.
- **
- **  It is set to 'gap> ' or 'brk> ' in the read-eval-print loops and changed
- **  to the partial prompt '> ' in 'Read' after the first symbol is read.
- */
-/* TL: extern  const Char *    Prompt; */
 
 /****************************************************************************
 **
@@ -290,17 +279,6 @@ UInt CloseInputLog(void);
 */
 void SetPrompt(const char * prompt);
 
-/****************************************************************************
- **
- *V  PrintPromptHook . . . . . . . . . . . . . . function for printing prompt
- *V  EndLineHook . . . . . . . . . . . function called at end of command line
- **  
- **  These functions can be set on GAP-level. If they are not bound  the 
- **  default is: Instead of 'PrintPromptHook' the 'Prompt' is printed and
- **  instead of 'EndLineHook' nothing is done.
- */
-/* TL: extern Obj  PrintPromptHook; */
-extern Obj  EndLineHook;
 
 /****************************************************************************
 **
@@ -455,19 +433,18 @@ void LockCurrentOutput(BOOL lock);
 **  'Pr' is the output function. The first argument is a 'printf' like format
 **  string containing   up   to 2  '%'  format   fields,  specifying  how the
 **  corresponding arguments are to be  printed.  The two arguments are passed
-**  as  'long'  integers.   This  is possible  since every  C object  ('int',
-**  'char', pointers) except 'float' or 'double', which are not used  in GAP,
-**  can be converted to a 'long' without loss of information.
+**  as  'Int'  integers. This assumes that GAP is built on an architecture
+**  where each of the C types possibly passed as argument to 'Pr' ('int',
+**  'char', pointers) can be converted to 'Int' without loss of information.
 **
 **  The function 'Pr' currently support the following '%' format  fields:
 **  '%c'    the corresponding argument represents a character,  usually it is
-**          its ASCII or EBCDIC code, and this character is printed.
+**          its ASCII code, and this character is printed.
 **  '%s'    the corresponding argument is the address of  a  null  terminated
 **          character string which is printed.
-**  '%S'    the corresponding argument is the address of  a  null  terminated
-**          character string which is printed with escapes.
-**  '%g'    the corresponding argument is the address of an Obj which points
-**          to a string in STRING_REP format which is printed in '%s' format
+**  '%g'    the corresponding argument is the address of a T_STRING string
+**          object which is printed. This is similar to using '%s' to print
+**          CSTR_STRING(arg), but is safe during garbage collection.
 **  '%G'    the corresponding argument is the address of an Obj which points
 **          to a string in STRING_REP format which is printed in '%S' format
 **  '%C'    the corresponding argument is the address of an Obj which points
@@ -476,16 +453,10 @@ void LockCurrentOutput(BOOL lock);
 **          Between the '%' and the 'd' an integer might be used  to  specify
 **          the width of a field in which the integer is right justified.  If
 **          the first character is '0' 'Pr' pads with '0' instead of <space>.
-**  '%i'    is a synonym of %d, in line with recent C library developments
-**  '%I'    print an identifier, given as a null terminated character string.
-**  '%H'    print an identifier, given as GAP string in STRING_REP
+**  '%I'    print an identifier, given as GAP string in STRING_REP.
 **  '%>'    increment the indentation level.
 **  '%<'    decrement the indentation level.
 **  '%%'    can be used to print a single '%' character. No argument is used.
-**
-**  You must always  cast the arguments to  '(long)' to avoid  problems  with
-**  those compilers with a default integer size of 16 instead of 32 bit.  You
-**  must pass 0 if you don't make use of an argument to please lint.
 */
 
 void Pr(const Char * format, Int arg1, Int arg2);
