@@ -73,7 +73,7 @@ BOOL IS_MACFLOAT(Obj obj)
 static Obj TYPE_MACFLOAT;
 
 static Obj TypeMacfloat(Obj val)
-{  
+{
     return TYPE_MACFLOAT;
 }
 
@@ -164,7 +164,7 @@ static Int LtMacfloat(Obj macfloatL, Obj macfloatR)
 
 /****************************************************************************
 **
-*F  SaveMacfloat( <macfloat> ) . . . . . . . . . . . . . . save a Macfloatean 
+*F  SaveMacfloat( <macfloat> ) . . . . . . . . . . . . . . save a Macfloatean
 **
 */
 #ifdef GAP_ENABLE_SAVELOAD
@@ -179,7 +179,7 @@ static void SaveMacfloat(Obj obj)
 
 /****************************************************************************
 **
-*F  LoadMacfloat( <macfloat> ) . . . . . . . . . . . . . . load a Macfloatean 
+*F  LoadMacfloat( <macfloat> ) . . . . . . . . . . . . . . load a Macfloatean
 **
 */
 #ifdef GAP_ENABLE_SAVELOAD
@@ -201,7 +201,7 @@ Obj NEW_MACFLOAT( Double val )
 
 /****************************************************************************
 **
-*F  ZeroMacfloat(<macfloat> ) . . . . . . . . . . . . . . . . . . . return the zero 
+*F  ZeroMacfloat(<macfloat> ) . . . . . . . . . . . . . . . . . . . return the zero
 **
 */
 
@@ -225,7 +225,7 @@ static Obj AInvMacfloat(Obj f)
 
 /****************************************************************************
 **
-*F  OneMacfloat(<macfloat> ) . . . . . . . . . . . . . . . . . . . return the one 
+*F  OneMacfloat(<macfloat> ) . . . . . . . . . . . . . . . . . . . return the one
 **
 */
 
@@ -359,7 +359,7 @@ static Obj FuncMACFLOAT_STRING(Obj self, Obj s)
   char * endptr;
   UChar *sp = CHARS_STRING(s);
   Obj res= NEW_MACFLOAT((Double) STRTOD((char *)sp,&endptr));
-  if ((UChar *)endptr != sp + GET_LEN_STRING(s)) 
+  if ((UChar *)endptr != sp + GET_LEN_STRING(s))
     return Fail;
   return res;
 }
@@ -436,7 +436,7 @@ MAKEMATHPRIMITIVE(GAMMA,tgamma)
 static Obj FuncSIGN_MACFLOAT(Obj self, Obj f)
 {
   Double vf = VAL_MACFLOAT(f);
-  
+
   return vf == 0. ? INTOBJ_INT(0) : signbit(vf) ? INTOBJ_INT(-1) : INTOBJ_INT(1);
 }
 
@@ -490,7 +490,7 @@ static Obj FuncSTRING_DIGITS_MACFLOAT(Obj self, Obj gapprec, Obj f)
   Char buf[1024];
   Obj str;
   int prec = INT_INTOBJ(gapprec);
-  if (prec > 40) /* too much anyways, and would risk buffer overrun */
+  if (prec > 40) // too much anyways, and would risk buffer overrun
     prec = 40;
   PrintMacfloatToBuf(buf, sizeof(buf), VAL_MACFLOAT(f), prec);
   str = MakeString(buf);
@@ -598,39 +598,39 @@ static Int InitKernel (
     // set the bag type names (for error messages and debugging)
     InitBagNamesFromTable( BagNames );
 
-    /* install the marking functions for macfloatean values                    */
+    // install the marking functions for macfloatean values
     InitMarkFuncBags( T_MACFLOAT, MarkNoSubBags );
 #ifdef HPCGAP
     MakeBagTypePublic( T_MACFLOAT );
 #endif
 
-    /* init functions */
+    // init functions
     InitHdlrFuncsFromTable( GVarFuncs );
 
-    /* install the type function                                           */
+    // install the type function
     ImportGVarFromLibrary( "TYPE_MACFLOAT", &TYPE_MACFLOAT );
     TypeObjFuncs[ T_MACFLOAT ] = TypeMacfloat;
 
 #ifdef GAP_ENABLE_SAVELOAD
-    /* install the saving functions                                       */
+    // install the saving functions
     SaveObjFuncs[ T_MACFLOAT ] = SaveMacfloat;
 
-    /* install the loading functions                                       */
+    // install the loading functions
     LoadObjFuncs[ T_MACFLOAT ] = LoadMacfloat;
 #endif
 
-    /* install the printer for macfloatean values                              */
+    // install the printer for macfloatean values
     PrintObjFuncs[ T_MACFLOAT ] = PrintMacfloat;
 
-    /* install the comparison functions                                    */
+    // install the comparison functions
     EqFuncs[ T_MACFLOAT ][ T_MACFLOAT ] = EqMacfloat;
     LtFuncs[ T_MACFLOAT ][ T_MACFLOAT ] = LtMacfloat;
 
-    /* allow method selection to protest against comparisons of float and int */
+    // allow method selection to protest against comparisons of float and int
     for (int t = T_INT; t <= T_CYC; t++)
         EqFuncs[T_MACFLOAT][t] = EqFuncs[t][T_MACFLOAT] = EqObject;
 
-    /* install the unary arithmetic methods                                */
+    // install the unary arithmetic methods
     ZeroSameMutFuncs[T_MACFLOAT] = ZeroMacfloat;
     ZeroMutFuncs[ T_MACFLOAT ] = ZeroMacfloat;
     AInvMutFuncs[ T_MACFLOAT ] = AInvMacfloat;
@@ -638,7 +638,7 @@ static Int InitKernel (
     OneSameMut[T_MACFLOAT] = OneMacfloat;
     InvFuncs [ T_MACFLOAT ] = InvMacfloat;
 
-    /* install binary arithmetic methods */
+    // install binary arithmetic methods
     ProdFuncs[ T_MACFLOAT ][ T_MACFLOAT ] = ProdMacfloat;
     PowFuncs [ T_MACFLOAT ][ T_MACFLOAT ] = PowMacfloat;
     SumFuncs[ T_MACFLOAT ][ T_MACFLOAT ] = SumMacfloat;
@@ -647,14 +647,14 @@ static Int InitKernel (
     LQuoFuncs [ T_MACFLOAT ][ T_MACFLOAT ] = LQuoMacfloat;
     ModFuncs [ T_MACFLOAT ][ T_MACFLOAT ] = ModMacfloat;
     SumFuncs [ T_INT ][ T_MACFLOAT ] = SumIntMacfloat;
-    
-    /* Probably support mixed ops with small ints in the kernel as well
-       on any reasonable system, all small ints should have macfloat equivalents
 
-       Anything else, like mixed ops with rationals, we can leave to the library
-       at least for a while */
-     
-    
+    // Probably support mixed ops with small ints in the kernel as well
+    // on any reasonable system, all small ints should have macfloat
+    // equivalents
+
+    // Anything else, like mixed ops with rationals, we can leave to the
+    // library at least for a while */
+
     return 0;
 }
 
@@ -666,7 +666,7 @@ static Int InitKernel (
 static Int InitLibrary (
     StructInitInfo *    module )
 {
-    /* init functions */
+    // init functions
     InitGVarFuncsFromTable( GVarFuncs );
 
     return 0;
