@@ -60,11 +60,7 @@
 **    We also use 1 bit to mark that we have executed this statement, so
 **    we can (if we want to) only output each executed statement once.
 **
-**    We use this information in a few ways:
-**
-**  1) Output a straight list of every executed statement
-**  2) Provide coloured printing (by wrapping PrintStatFuncs and PrintExprFuncs)
-**     which show which parts of an expression have been executed
+**  We use this information to output a straight list of every executed statement.
 **
 **  There are not that many tricky cases here. We have to be careful that
 **  some Expr are integers or local variables, and not touch those.
@@ -83,9 +79,8 @@
 **     we provide -P (profiling) and -c (code coverage) options to the GAP
 **     executable so the user can start before code loading starts
 **
-**  3) Operating at just a line basis can sometimes be too course. We can
-**     see this when we use ActivateProfileColour. However, without some
-**     serious additional overheads, I can't see how to provide this
+**  3) Operating at just a line basis can sometimes be too coarse. However,
+**     without some serious additional overheads, I can't see how to provide this
 **     functionality in output (basically we would have to store
 **     line and character positions for the start and end of every expression).
 **
@@ -115,7 +110,7 @@ static Obj OutputtedFilenameList;
 
 struct StatementLocation
 {
-    int fileID;
+    int fileid;
     int line;
 };
 
@@ -135,8 +130,6 @@ static struct ProfileState
   int StreamWasPopened;
   // Are we currently outputting repeats (false=code coverage)
   int OutputRepeats;
-  // Are we colouring output (not related to profiling directly)
-  int ColouringOutput;
 
   // Used to generate 'X' statements, to make sure we correctly
   // attach each function call to the line it was executed on
@@ -156,10 +149,10 @@ static struct ProfileState
   int profiledThread;
 #endif
 
-  /* Have we previously profiled this execution of GAP? We need this because
-  ** code coverage doesn't work more than once, as we use a bit in each Stat
-  ** to mark if we previously executed this statement, which we can't
-  ** clear */
+  // Have we previously profiled this execution of GAP? We need this because
+  // code coverage doesn't work more than once, as we use a bit in each Stat
+  // to mark if we previously executed this statement, which we can't
+  // clear
   UInt profiledPreviously;
 
   Int LongJmpOccurred;
@@ -239,6 +232,52 @@ static void CheckLeaveFunctionsAfterLongjmp(void)
     }
 }
 
+// Escape a string for serialization in a JSON file, following the
+// escaping rules laid out at json.org.
+static Obj JsonEscapeString(Obj param)
+{
+    Int lenString = LEN_LIST(param);
+
+    // Allocate an output string with twice the size of the input
+    // string, as in the worst case every single has to be escaped.
+    Obj     copy = NEW_STRING(lenString * 2);
+    UChar * in = CHARS_STRING(param);
+    UChar * base = CHARS_STRING(copy);
+    UChar * out = base;
+
+    for (Int i = 0; i < lenString; ++i) {
+        UChar u = in[i];
+        switch (u) {
+        case '\\':
+        case '"':
+        case '/':
+            out[0] = '\\';
+            out[1] = u;
+            out += 2;
+            break;
+#define ESCAPE_CASE(x, y)                                                    \
+    case x:                                                                  \
+        out[0] = '\\';                                                       \
+        out[1] = y;                                                          \
+        out += 2;                                                            \
+        break;
+            ESCAPE_CASE('\b', 'b');
+            ESCAPE_CASE('\t', 't');
+            ESCAPE_CASE('\n', 'n');
+            ESCAPE_CASE('\f', 'f');
+            ESCAPE_CASE('\r', 'r');
+#undef ESCAPE_CASE
+        default:
+            *(out++) = u;
+        }
+    }
+
+    SET_LEN_STRING(copy, out - base);
+    ResizeBag(copy, SIZEBAG_STRINGLEN(out - base));
+    return copy;
+}
+
+
 static inline void outputFilenameIdIfRequired(UInt id)
 {
     if (id == 0) {
@@ -249,7 +288,8 @@ static inline void outputFilenameIdIfRequired(UInt id)
         AssPlist(OutputtedFilenameList, id, True);
         fprintf(profileState.Stream,
                 "{\"Type\":\"S\",\"File\":\"%s\",\"FileId\":%d}\n",
-                CONST_CSTR_STRING(GetCachedFilename(id)), (int)id);
+                CONST_CSTR_STRING(JsonEscapeString(GetCachedFilename(id))),
+                (int)id);
     }
 }
 
@@ -272,20 +312,25 @@ static void HookedLineOutput(Obj func, char type)
     UInt endline = GET_ENDLINE_BODY(body);
 
     Obj name = NAME_FUNC(func);
-    const Char *name_c = name ? CONST_CSTR_STRING(name) : "nameless";
+    if (name) {
+        name = JsonEscapeString(name);
+    }
 
     Obj         filename = GET_FILENAME_BODY(body);
-    UInt        fileID = GET_GAPNAMEID_BODY(body);
-    outputFilenameIdIfRequired(fileID);
+    UInt        fileid = GET_GAPNAMEID_BODY(body);
+    outputFilenameIdIfRequired(fileid);
     const Char *filename_c = "<missing filename>";
     if(filename != Fail && filename != NULL)
-      filename_c = CONST_CSTR_STRING(filename);
+        filename_c = CONST_CSTR_STRING(JsonEscapeString(filename));
+
+    // Do this here to avoid GCs before string is used
+    const Char * name_c = name ? CONST_CSTR_STRING(name) : "nameless";
 
     if(type == 'I' && profileState.lastNotOutputted.line != -1)
     {
       fprintf(profileState.Stream, "{\"Type\":\"X\",\"Line\":%d,\"FileId\":%d}\n",
               (int)profileState.lastNotOutputted.line,
-              (int)profileState.lastNotOutputted.fileID);
+              (int)profileState.lastNotOutputted.fileid);
     }
 
     // We output 'File' here for compatibility with
@@ -295,7 +340,7 @@ static void HookedLineOutput(Obj func, char type)
                                  "d,\"EndLine\":%d,\"File\":\"%s\","
                                  "\"FileId\":%d}\n",
             type, name_c, (int)startline, (int)endline, filename_c,
-            (int)fileID);
+            (int)fileid);
   }
   HashUnlock(&profileState);
 }
@@ -399,7 +444,7 @@ void InformProfilingThatThisIsAForkedGAP(void)
         fcloseMaybeCompressed(&profileState);
         fopenMaybeCompressed(filenamecpy, &profileState);
         outputVersionInfo();
-        // Need to flush list of outputed files, as we will start a fresh file
+        // Need to flush list of outputted files, as we will start a fresh file
         OutputtedFilenameList = NEW_PLIST(T_PLIST, 0);
     }
     HashUnlock(&profileState);
@@ -434,10 +479,10 @@ static inline Int8 getTicks(void)
 }
 
 
-static inline void printOutput(UInt line, int nameid, int exec, int visited)
+static inline void printOutput(int fileid, int line, BOOL exec, BOOL visited)
 {
     if (profileState.lastOutputted.line != line ||
-        profileState.lastOutputted.fileID != nameid ||
+        profileState.lastOutputted.fileid != fileid ||
         profileState.lastOutputtedExec != exec) {
 
         if (profileState.OutputRepeats) {
@@ -458,46 +503,45 @@ static inline void printOutput(UInt line, int nameid, int exec, int visited)
                     ticksDone = (ticks / profileState.minimumProfileTick) *
                                 profileState.minimumProfileTick;
                 }
-                outputFilenameIdIfRequired(nameid);
+                outputFilenameIdIfRequired(fileid);
                 fprintf(profileState.Stream,
                         "{\"Type\":\"%c\",\"Ticks\":%d,\"Line\":%d,"
                         "\"FileId\":%d}\n",
-                        exec ? 'E' : 'R', ticksDone, (int)line, (int)nameid);
+                        exec ? 'E' : 'R', ticksDone, (int)line, (int)fileid);
                 profileState.lastOutputtedTime = newticks;
                 profileState.lastNotOutputted.line = -1;
                 profileState.lastOutputted.line = line;
-                profileState.lastOutputted.fileID = nameid;
+                profileState.lastOutputted.fileid = fileid;
                 profileState.lastOutputtedExec = exec;
             }
             else {
                 profileState.lastNotOutputted.line = line;
-                profileState.lastNotOutputted.fileID = nameid;
+                profileState.lastNotOutputted.fileid = fileid;
             }
         }
         else {
-            outputFilenameIdIfRequired(nameid);
+            outputFilenameIdIfRequired(fileid);
             fprintf(profileState.Stream,
                     "{\"Type\":\"%c\",\"Line\":%d,\"FileId\":%d}\n",
-                    exec ? 'E' : 'R', (int)line, (int)nameid);
+                    exec ? 'E' : 'R', (int)line, (int)fileid);
             profileState.lastOutputted.line = line;
-            profileState.lastOutputted.fileID = nameid;
+            profileState.lastOutputted.fileid = fileid;
             profileState.lastOutputtedExec = exec;
             profileState.lastNotOutputted.line = -1;
         }
     }
 }
 
+// type : the type of the statement
 // exec : are we executing this statement
 // visit: Was this statement previously visited (that is, executed)
-static inline void outputStat(Stat stat, int exec, int visited)
+static inline void
+outputStat(Int fileid, int line, int type, BOOL exec, BOOL visited)
 {
-    UInt line;
-    int  nameid;
-
     // Explicitly skip these two cases, as they are often specially handled
     // and also aren't really interesting statements (something else will
     // be executed whenever they are).
-    if (TNUM_STAT(stat) == EXPR_TRUE || TNUM_STAT(stat) == EXPR_FALSE) {
+    if (type == EXPR_TRUE || type == EXPR_FALSE) {
         return;
     }
 
@@ -508,19 +552,17 @@ static inline void outputStat(Stat stat, int exec, int visited)
         return;
     }
 
-    nameid = getFilenameIdOfCurrentFunction();
-    outputFilenameIdIfRequired(nameid);
+    outputFilenameIdIfRequired(fileid);
 
     // Statement not attached to a file
-    if (nameid == 0) {
+    if (fileid == 0) {
         return;
     }
 
-    line = LINE_STAT(stat);
-    printOutput(line, nameid, exec, visited);
+    printOutput(fileid, line, exec, visited);
 }
 
-static inline void outputInterpretedStat(Int file, Int line, Int exec)
+static inline void outputInterpretedStat(int fileid, int line, BOOL exec)
 {
     CheckLeaveFunctionsAfterLongjmp();
 
@@ -529,14 +571,14 @@ static inline void outputInterpretedStat(Int file, Int line, Int exec)
         return;
     }
 
-    outputFilenameIdIfRequired(file);
+    outputFilenameIdIfRequired(fileid);
 
     // Statement not attached to a file
-    if (file == 0) {
+    if (fileid == 0) {
         return;
     }
 
-    printOutput(line, file, exec, 0);
+    printOutput(fileid, line, exec, 0);
 }
 
 static void visitStat(Stat stat)
@@ -546,7 +588,7 @@ static void visitStat(Stat stat)
     return;
 #endif
 
-  int visited = VISITED_STAT(stat);
+  BOOL visited = VISITED_STAT(stat);
 
   if (!visited) {
     SET_VISITED_STAT(stat);
@@ -554,12 +596,13 @@ static void visitStat(Stat stat)
 
   if (profileState.OutputRepeats || !visited) {
     HashLock(&profileState);
-    outputStat(stat, 1, visited);
+    outputStat(getFilenameIdOfCurrentFunction(), LINE_STAT(stat),
+               TNUM_STAT(stat), TRUE, visited);
     HashUnlock(&profileState);
   }
 }
 
-static void visitInterpretedStat(Int file, Int line)
+static void visitInterpretedStat(int fileid, int line)
 {
 #ifdef HPCGAP
     if (profileState.profiledThread != TLS(threadID))
@@ -567,7 +610,7 @@ static void visitInterpretedStat(Int file, Int line)
 #endif
 
     HashLock(&profileState);
-    outputInterpretedStat(file, line, 1);
+    outputInterpretedStat(fileid, line, TRUE);
     HashUnlock(&profileState);
 }
 
@@ -580,20 +623,20 @@ static void visitInterpretedStat(Int file, Int line)
 ** check we executed something on those lines!
 **/
 
-static void registerStat(Stat stat)
+static void registerStat(int fileid, int line, int type)
 {
     HashLock(&profileState);
     if (profileState.status == Profile_Active) {
-      outputStat(stat, 0, 0);
+        outputStat(fileid, line, type, FALSE, FALSE);
     }
     HashUnlock(&profileState);
 }
 
-static void registerInterpretedStat(Int file, Int line)
+static void registerInterpretedStat(int fileid, int line)
 {
     HashLock(&profileState);
     if (profileState.status == Profile_Active) {
-        outputInterpretedStat(file, line, 0);
+        outputInterpretedStat(fileid, line, FALSE);
     }
     HashUnlock(&profileState);
 }
@@ -614,7 +657,7 @@ enableAtStartup(char * filename, Int repeats, TickMethod tickMethod)
     if (profileState.status == Profile_Active) {
         Panic("-P or -C can only be passed once\n");
     }
-    
+
     profileState.OutputRepeats = repeats;
 
     fopenMaybeCompressed(filename, &profileState);
@@ -672,7 +715,7 @@ Int enableMemoryProfilingAtStartup(Char ** argv, void * dummy)
 }
 
 static Obj FuncACTIVATE_PROFILING(Obj self,
-                                  Obj filename, /* filename to write to */
+                                  Obj filename, // filename to write to
                                   Obj coverage,
                                   Obj wallTime,
                                   Obj recordMem,
@@ -798,128 +841,6 @@ static Obj FuncIsLineByLineProfileActive(Obj self)
   }
 }
 
-/****************************************************************************
-**
-** We are now into the functions which deal with colouring printing output.
-** This code basically wraps all the existing print functions and will colour
-** their output either green or red depending on if statements are marked
-** as being executed.
-*/
-
-static Int CurrentColour = 0;
-
-static void setColour(void)
-{
-  if(CurrentColour == 0) {
-    Pr("\x1b[0m", 0, 0);
-  }
-  else if(CurrentColour == 1) {
-    Pr("\x1b[32m", 0, 0);
-  }
-  else if(CurrentColour == 2) {
-    Pr("\x1b[31m", 0, 0);
-  }
-}
-
-static void ProfilePrintStatPassthrough(Stat stat)
-{
-  Int SavedColour = CurrentColour;
-  if(VISITED_STAT(stat)) {
-    CurrentColour = 1;
-  }
-  else {
-    CurrentColour = 2;
-  }
-  setColour();
-  OriginalPrintStatFuncsForHook[TNUM_STAT(stat)](stat);
-  CurrentColour = SavedColour;
-  setColour();
-}
-
-static void ProfilePrintExprPassthrough(Expr stat)
-{
-  Int SavedColour = -1;
-  /* There are two cases we must pass through without touching */
-  /* From TNUM_EXPR */
-  if(IS_REF_LVAR(stat)) {
-    OriginalPrintExprFuncsForHook[EXPR_REF_LVAR](stat);
-  } else if(IS_INTEXPR(stat)) {
-    OriginalPrintExprFuncsForHook[EXPR_INT](stat);
-  } else {
-    SavedColour = CurrentColour;
-    if(VISITED_STAT(stat)) {
-      CurrentColour = 1;
-    }
-    else {
-      CurrentColour = 2;
-    }
-    setColour();
-    OriginalPrintExprFuncsForHook[TNUM_STAT(stat)](stat);
-    CurrentColour = SavedColour;
-    setColour();
-  }
-}
-
-static struct PrintHooks profilePrintHooks =
-  {ProfilePrintStatPassthrough, ProfilePrintExprPassthrough};
-
-static Obj activate_colored_output_from_profile(void)
-{
-    HashLock(&profileState);
-
-    if(profileState.ColouringOutput) {
-      HashUnlock(&profileState);
-      return Fail;
-    }
-
-    ActivatePrintHooks(&profilePrintHooks);
-
-    profileState.ColouringOutput = 1;
-    CurrentColour = 0;
-    setColour();
-
-    HashUnlock(&profileState);
-
-    return True;
-}
-
-static Obj deactivate_colored_output_from_profile(void)
-{
-  HashLock(&profileState);
-
-  if(!profileState.ColouringOutput) {
-    HashUnlock(&profileState);
-    return Fail;
-  }
-
-  DeactivatePrintHooks(&profilePrintHooks);
-
-  profileState.ColouringOutput = 0;
-  CurrentColour = 0;
-  setColour();
-
-  HashUnlock(&profileState);
-
-  return True;
-}
-
-static Obj FuncACTIVATE_COLOR_PROFILING(Obj self, Obj arg)
-{
-  if(arg == True)
-  {
-    return activate_colored_output_from_profile();
-  }
-  else if(arg == False)
-  {
-    return deactivate_colored_output_from_profile();
-  }
-  else
-    return Fail;
-}
-
-
-
-
 /****************************************************************************
 **
 *F * * * * * * * * * * * * * initialize module * * * * * * * * * * * * * * *
@@ -939,7 +860,6 @@ static StructGVarFunc GVarFuncs[] = {
                     resolution),
     GVAR_FUNC_0ARGS(DEACTIVATE_PROFILING),
     GVAR_FUNC_0ARGS(IsLineByLineProfileActive),
-    GVAR_FUNC_1ARGS(ACTIVATE_COLOR_PROFILING, arg),
     { 0, 0, 0, 0, 0 }
 };
 
@@ -951,7 +871,7 @@ static StructGVarFunc GVarFuncs[] = {
 static Int InitLibrary (
     StructInitInfo *    module )
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitGVarFuncsFromTable( GVarFuncs );
 
     profileState.visitedDepths = NEW_PLIST(T_PLIST, 0);
