@@ -51,7 +51,7 @@ static UInt1* LBPointer;
 static UInt1* LBEnd;
 static Obj userHomeExpand;
 
-static Int OpenForSave( Obj fname ) 
+static Int OpenForSave( Obj fname )
 {
   if (SaveFile != -1)
     {
@@ -77,12 +77,12 @@ static void CloseAfterSave( void )
     }
 
   if (SyWrite(SaveFile, LoadBuffer, LBPointer - LoadBuffer) < 0)
-    ErrorQuit("Cannot write to file, see 'LastSystemError();'\n", 0, 0);
+    ErrorQuit("Cannot write to file, see 'LastSystemError();'", 0, 0);
   SyFclose(SaveFile);
   SaveFile = -1;
 }
 
-static void OpenForLoad( const Char *fname ) 
+static void OpenForLoad( const Char *fname )
 {
   if (LoadFile != -1)
     {
@@ -109,7 +109,7 @@ static void CloseAfterLoad( void )
 static void SAVE_BYTE_BUF(void)
 {
   if (SyWrite(SaveFile, LoadBuffer, LBEnd - LoadBuffer) < 0)
-    ErrorQuit("Cannot write to file, see 'LastSystemError();'\n", 0, 0);
+    ErrorQuit("Cannot write to file, see 'LastSystemError();'", 0, 0);
   LBPointer = LoadBuffer;
   return;
 }
@@ -127,7 +127,7 @@ static UInt1 LOAD_BYTE_BUF(void)
     }
   LBEnd = LoadBuffer + ret;
   LBPointer = LoadBuffer;
-  return *LBPointer++;   
+  return *LBPointer++;
 }
 
 #define LOAD_BYTE()    (UInt1)((LBPointer >= LBEnd) ?\
@@ -329,7 +329,7 @@ static void SaveBagData (Bag bag )
   SaveUInt1(header->flags);
   SaveUInt(header->size);
 
-  /* dispatch */
+  // dispatch
   (*(SaveObjFuncs[ header->type]))(bag);
 }
 
@@ -338,8 +338,8 @@ static void LoadBagData ( void )
 {
   Bag bag;
   UInt type, flags, size;
-  
-  /* Recover the size & type */
+
+  // Recover the size & type
   type = LoadUInt1();
   flags = LoadUInt1();
   size = LoadUInt();
@@ -347,10 +347,10 @@ static void LoadBagData ( void )
   if (TNAM_TNUM(type) == NULL)
     Panic("Bad type %d, size %d\n", (int)type, (int)size);
 
-  /* Get GASMAN to set up the bag for me */
+  // Get GASMAN to set up the bag for me
   bag = NextBagRestoring( type, flags, size );
-  
-  /* dispatch */
+
+  // dispatch
   (*(LoadObjFuncs[ type ]))(bag);
 }
 
@@ -398,7 +398,7 @@ static void CheckEndiannessMarker( void )
   if (x != 0x0102030405060708L)
 #else
   if (x != 0x01020304L)
-#endif  
+#endif
     {
       Panic("Saved workspace with incompatible byte order");
     }
@@ -445,10 +445,10 @@ static Bag hit;
 
 static void ScanBag( Bag bag)
 {
-  if (hit == (Bag)0 && 
-      SIZE_BAG(bag) >= fb_minsize && 
-      SIZE_BAG(bag) <= fb_maxsize && 
-      TNUM_BAG(bag) == fb_tnum) 
+  if (hit == (Bag)0 &&
+      SIZE_BAG(bag) >= fb_minsize &&
+      SIZE_BAG(bag) <= fb_maxsize &&
+      TNUM_BAG(bag) == fb_tnum)
     hit = bag;
 }
 
@@ -508,18 +508,18 @@ static Char * GetKernelDescription(void)
 static void WriteSaveHeader( void )
 {
   UInt i;
-  
+
   SaveCStr("GAP workspace");
   SaveCStr(GetKernelDescription());
 
-#ifdef SYS_IS_64_BIT             
+#ifdef SYS_IS_64_BIT
   SaveCStr("64 bit");
 #else
   SaveCStr("32 bit");
 #endif
 
   WriteEndiannessMarker();
-  
+
   SaveCStr("Counts and Sizes");
   for (i = 0; i < GlobalBags.nr; i++) {
       GAP_ASSERT(GlobalBags.cookie[i] != NULL);
@@ -547,35 +547,35 @@ Obj SaveWorkspace( Obj fname )
 
   if (!IsStringConv(fname))
     ErrorQuit("usage: SaveWorkspace( <filename> )",0,0);
-  /* maybe expand fname starting with ~/...   */
+  // maybe expand fname starting with ~/...
   fullname = Call1ArgsInNewReader(userHomeExpand, fname);
-  
+
   if (ModulesPreSave())
     return Fail;
 
-  /* Do a full garbage collection */
+  // Do a full garbage collection
   CollectBags( 0, 1);
-  
-  /* Add indices in link words of all bags, for saving inter-bag references */
+
+  // Add indices in link words of all bags, for saving inter-bag references
   NextSaveIndex = 1;
   CallbackForAllBags( AddSaveIndex );
 
-  /* Now do the work */
+  // Now do the work
   result = Fail;
   if (!OpenForSave( fullname ))
     {
       result = True;
       WriteSaveHeader();
       SaveCStr("Bag data");
-      SortHandlers( 1 ); /* Sort by address to speed up CookieOfHandler */
+      SortHandlers( 1 ); // Sort by address to speed up CookieOfHandler
       CallbackForAllBags( SaveBagData );
       CloseAfterSave();
     }
-      
-  /* Finally, reset all the link words */
+
+  // Finally, reset all the link words
   CallbackForAllBags( RemoveSaveIndex );
-  
-  /* Restore situation by calling all post-save methods */
+
+  // Restore situation by calling all post-save methods
   ModulesPostSave();
 
   return result;
@@ -601,10 +601,10 @@ void LoadWorkspace( Char * fname )
   Char buf[256];
   Obj * glob;
 
-  /* Open saved workspace  */
+  // Open saved workspace
   OpenForLoad( fname );
 
-  /* Check file header */
+  // Check file header
 
   LoadCStr(buf,256);
   if (strncmp (buf, "GAP ", 4) != 0) {
@@ -620,7 +620,7 @@ void LoadWorkspace( Char * fname )
      }
 
      LoadCStr(buf,256);
-#ifdef SYS_IS_64_BIT             
+#ifdef SYS_IS_64_BIT
      if (!streq(buf,"64 bit"))
 #else
      if (!streq(buf,"32 bit"))
@@ -630,26 +630,26 @@ void LoadWorkspace( Char * fname )
         }
   } else {
      Panic("File %s probably isn't a GAP workspace", fname);
-  } 
-  
+  }
+
   CheckEndiannessMarker();
-  
+
   LoadCStr(buf,256);
   if (!streq(buf,"Counts and Sizes"))
     {
       Panic("Bad divider");
     }
-  
+
   nGlobs = LoadUInt();
   nBags = LoadUInt();
   maxSize = LoadUInt();
 
-  /* Make sure there is enough room, and signal GASMAN that
-     we are starting a restore */
+  // Make sure there is enough room, and signal GASMAN that
+  // we are starting a restore
   StartRestoringBags(nBags, maxSize);
 
-  /* The restoring kernel must have at least as many compiled modules
-     as the saving one. */
+  // The restoring kernel must have at least as many compiled modules
+  // as the saving one.
   LoadCStr(buf,256);
   if (!streq(buf,"Loaded Modules"))
     {
@@ -657,7 +657,7 @@ void LoadWorkspace( Char * fname )
     }
   LoadModules();
 
-  /* Now the kernel variables that point into the workspace */
+  // Now the kernel variables that point into the workspace
   LoadCStr(buf,256);
   if (!streq(buf,"Kernel to WS refs"))
     {
@@ -687,7 +687,7 @@ void LoadWorkspace( Char * fname )
     {
       Panic("Bad divider");
     }
-  
+
   SortHandlers(2);
   for (i = 0; i < nBags; i++)
     LoadBagData();
@@ -815,11 +815,11 @@ static Int InitKernel (
     LBPointer = LoadBuffer;
     LBEnd = LoadBuffer;
 
-    /* allow ~/... expansion in SaveWorkspace                              */ 
+    // allow ~/... expansion in SaveWorkspace
     ImportFuncFromLibrary("UserHomeExpand", &userHomeExpand);
 #endif
 
-    /* init filters and functions                                          */
+    // init filters and functions
     InitHdlrFuncsFromTable( GVarFuncs );
 
     return 0;
@@ -833,7 +833,7 @@ static Int InitKernel (
 static Int InitLibrary (
     StructInitInfo *    module )
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitGVarFuncsFromTable( GVarFuncs );
 
     return 0;
