@@ -1703,11 +1703,11 @@ static StructGVarFunc GVarFuncs[] = {
     GVAR_FUNC_1ARGS(OUTPUT_LOG_TO, filename),
     GVAR_FUNC_1ARGS(OUTPUT_LOG_TO_STREAM, filename),
     GVAR_FUNC_0ARGS(CLOSE_OUTPUT_LOG_TO),
-    GVAR_FUNC_XARGS(Print, -1, "arg..."),
-    GVAR_FUNC_XARGS(PRINT_TO, -1, "arg..."),
-    GVAR_FUNC_XARGS(PRINT_TO_STREAM, -1, "arg..."),
-    GVAR_FUNC_XARGS(APPEND_TO, -1, "arg..."),
-    GVAR_FUNC_XARGS(APPEND_TO_STREAM, -1, "arg..."),
+    GVAR_FUNC_XARGS(Print, -1, "arg"),
+    GVAR_FUNC_XARGS(PRINT_TO, -1, "arg"),
+    GVAR_FUNC_XARGS(PRINT_TO_STREAM, -1, "arg"),
+    GVAR_FUNC_XARGS(APPEND_TO, -1, "arg"),
+    GVAR_FUNC_XARGS(APPEND_TO_STREAM, -1, "arg"),
     GVAR_FUNC_0ARGS(TmpName),
     GVAR_FUNC_0ARGS(TmpDirectory),
     GVAR_FUNC_1ARGS(RemoveFile, filename),
