@@ -36,8 +36,8 @@ enum { MAX_ARITY = 4 };
 
 typedef Obj (*CompileFuncT)(Obj node, Expr expr);
 typedef Obj (*CompileArgT)(Expr expr);
-typedef Expr (*CodeFuncT)(Obj node);
-typedef Expr (*CodeArgT)(Obj node);
+typedef Expr (*CodeFuncT)(CodeState * cs, Obj node);
+typedef Expr (*CodeArgT)(CodeState * cs, Obj node);
 
 
 typedef struct {
@@ -179,11 +179,19 @@ static Obj SyntaxTreeRNam(Expr expr)
     return NAME_RNAM(expr);
 }
 
+static Expr SyntaxTreeCodeRNamObj(CodeState * cs, Obj node)
+{
+    return RNamObj(node);
+}
+
+
 static Obj SyntaxTreeDefaultCompiler(Obj result, Expr expr)
 {
     int       i;
     UInt1     tnum;
     CompilerT comp;
+    BOOL      didvariadic = 0;
+    Int       offset = 0;
 
     // TODO: GAP_ASSERT tnum range
     tnum = TNUM_EXPR(expr);
@@ -194,36 +202,43 @@ static Obj SyntaxTreeDefaultCompiler(Obj result, Expr expr)
         Obj  compiled;
 
         if (comp.args[i].argcomp) {
-            Expr subexpr = READ_EXPR(expr, i);
+            Expr subexpr = READ_EXPR(expr, i + offset);
             compiled = comp.args[i].argcomp(subexpr);
         }
         else {
-            // special case: the last argument may have zero as decompiler,
-            // meaning that all remaining slots of the statement should be
-            // decompiled into a single list
-            const UInt offset = comp.arity - 1;
-            GAP_ASSERT(i == offset);
+            // special case: one argument may have zero as decompiler,
+            // which expresses that this slot is "variadic", and
+            // is decompiled into a single list
+            GAP_ASSERT(!didvariadic);
+            didvariadic = 1;
+            // Avoid warning about used variable when not in debug mode
+            (void)didvariadic;
 
-            // compile the complete rest into one statement
+            // compile the variadic part into a single list
             const UInt nr = SIZE_EXPR(expr) / sizeof(expr);
-            compiled = NEW_PLIST(T_PLIST, nr - offset);
-            for (; i < nr; i++) {
-                Expr subexpr = READ_EXPR(expr, i);
+            const UInt varlength = nr - (comp.arity - 1);
+            compiled = NEW_PLIST(T_PLIST, nr - (comp.arity - 1));
+            for (; offset < varlength; offset++) {
+                Expr subexpr = READ_EXPR(expr, i + offset);
                 // handle 0 to properly deal with EXPR_LIST
                 Obj obj = subexpr ? SyntaxTreeCompiler(subexpr) : 0;
                 PushPlist(compiled, obj);
             }
+            // offset gets set one bigger final time around loop
+            offset--;
         }
 
         AssPRec(result, rnam, compiled);
     }
+
+    GAP_ASSERT(i + offset == SIZE_EXPR(expr) / sizeof(expr));
     return result;
 }
 
-static Stat SyntaxTreeDefaultStatCoder(Obj);
-static Stat SyntaxTreeDefaultExprCoder(Obj);
+static Stat SyntaxTreeDefaultStatCoder(CodeState *, Obj);
+static Stat SyntaxTreeDefaultExprCoder(CodeState *, Obj);
 
-static Expr SyntaxTreeDefaultCoder(Obj node)
+static Expr SyntaxTreeDefaultCoder(CodeState * cs, Obj node)
 {
 
     RequirePlainRec("SyntaxTreeDefaultCoder", node);
@@ -233,7 +248,7 @@ static Expr SyntaxTreeDefaultCoder(Obj node)
     CompilerT comp = Compilers[tnum];
 
     if (comp.code != SyntaxTreeDefaultCoder) {
-        return comp.code(node);
+        return comp.code(cs, node);
     }
 
     // compute how big the statement/expression we are generating needs to
@@ -242,38 +257,51 @@ static Expr SyntaxTreeDefaultCoder(Obj node)
     UInt slots = comp.arity;
     UInt arity = comp.arity;
 
-    UInt isvararg = comp.arity > 0 && comp.args[comp.arity - 1].argcomp == 0;
-    Obj  vararglist;
+    Int varargloc = -1;
+    for (UInt i = 0; i < comp.arity; ++i) {
+        if (comp.args[i].argcomp == 0) {
+            GAP_ASSERT(varargloc == -1);
+            varargloc = i;
+        }
+    }
 
-    if (isvararg) {
-        arity--;
-        vararglist = ElmRecST(tnum, node, comp.args[arity].argname);
-        slots = arity + LEN_LIST(vararglist);
+    Obj vararglist = 0;
+
+    if (varargloc != -1) {
+        vararglist = ElmRecST(tnum, node, comp.args[varargloc].argname);
+        slots = arity - 1 + LEN_LIST(vararglist);
     }
 
     // reserve space for the statement or expressions
-    Expr expr = NewStatOrExpr(tnum, slots * sizeof(Expr), 0);
+    Expr expr = NewStatOrExpr(cs, tnum, slots * sizeof(Expr), 0);
 
-    UInt i;
+    Int  i;
+    UInt offset = 0;
 
     for (i = 0; i < arity; i++) {
-        Obj subast = ElmRecST(tnum, node, comp.args[i].argname);
-        WRITE_EXPR(expr, i, comp.args[i].argcode(subast));
-    }
-
-    if (isvararg) {
-        for (i = arity; i < slots; i++) {
-            Obj elem = ELM0_LIST(vararglist, i - arity + 1);
-            // Deal with empty entries in list expressions
-            if (elem == 0) {
-                WRITE_EXPR(expr, i, 0);
-            }
-            else if (comp.args[arity].isStat) {
-                WRITE_EXPR(expr, i, SyntaxTreeDefaultStatCoder(elem));
-            }
-            else {
-                WRITE_EXPR(expr, i, SyntaxTreeDefaultExprCoder(elem));
+        if (i == varargloc) {
+            for (; offset < LEN_LIST(vararglist); offset++) {
+                Obj elem = ELM0_LIST(vararglist, offset + 1);
+                // Deal with empty entries in list expressions
+                if (elem == 0) {
+                    WRITE_EXPR(cs, expr, i + offset, 0);
+                }
+                else if (comp.args[i].isStat) {
+                    WRITE_EXPR(cs, expr, i + offset,
+                               SyntaxTreeDefaultStatCoder(cs, elem));
+                }
+                else {
+                    WRITE_EXPR(cs, expr, i + offset,
+                               SyntaxTreeDefaultExprCoder(cs, elem));
+                }
             }
+            // offset gets set one bigger final time around loop
+            offset--;
+        }
+        else {
+            Obj subast = ElmRecST(tnum, node, comp.args[i].argname);
+            WRITE_EXPR(cs, expr, i + offset,
+                       comp.args[i].argcode(cs, subast));
         }
     }
 
@@ -282,28 +310,28 @@ static Expr SyntaxTreeDefaultCoder(Obj node)
 
 
 // Checks if node codes a statement
-static Stat SyntaxTreeDefaultStatCoder(Obj node)
+static Stat SyntaxTreeDefaultStatCoder(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeDefaultStatCoder", node);
     Int tnum = GetTypeTNum(node);
     if (!(FIRST_STAT_TNUM <= tnum && tnum <= LAST_STAT_TNUM))
         ErrorQuit("tried to code expression %s as statement",
                   (Int)Compilers[tnum].name, 0);
-    return (Stat)SyntaxTreeDefaultCoder(node);
+    return (Stat)SyntaxTreeDefaultCoder(cs, node);
 }
 
 // Checks if node codes an expression
-static Expr SyntaxTreeDefaultExprCoder(Obj node)
+static Expr SyntaxTreeDefaultExprCoder(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeDefaultExprCoder", node);
     UInt1 tnum = GetTypeTNum(node);
     if (!(FIRST_EXPR_TNUM <= tnum && tnum <= LAST_EXPR_TNUM))
         ErrorQuit("tried to code statement %s as expression",
                   (Int)Compilers[tnum].name, 0);
-    return (Expr)SyntaxTreeDefaultCoder(node);
+    return (Expr)SyntaxTreeDefaultCoder(cs, node);
 }
 
-static Expr SyntaxTreeCodeGVar(Obj name)
+static Expr SyntaxTreeCodeGVar(CodeState * cs, Obj name)
 {
     RequireStringRep("SyntaxTreeCodeGVar", name);
     return GVarName(CONST_CSTR_STRING(name));
@@ -315,7 +343,7 @@ static Obj SyntaxTreeRefLVar(Obj result, Expr expr)
     return result;
 }
 
-static Expr SyntaxTreeCodeRefLVar(Obj node)
+static Expr SyntaxTreeCodeRefLVar(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeRefLVar", node);
     Obj lvar = ElmRecST(EXPR_REF_LVAR, node, "lvar");
@@ -323,6 +351,11 @@ static Expr SyntaxTreeCodeRefLVar(Obj node)
     return REF_LVAR_LVAR(INT_INTOBJ(lvar));
 }
 
+static Expr SyntaxTreeCodeObjInt(CodeState * cs, Obj node)
+{
+    return UInt_ObjInt(node);
+}
+
 static Obj SyntaxTreeEvalCompiler(Obj result, Expr expr)
 {
     pauseProfiling();
@@ -367,22 +400,22 @@ static Obj SyntaxTreeRangeExpr(Obj result, Expr expr)
     return result;
 }
 
-static Expr SyntaxTreeCodeRangeExpr(Obj node)
+static Expr SyntaxTreeCodeRangeExpr(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeRangeExpr", node);
     UInt hassecond = ISB_REC(node, RNamName("second"));
     UInt size = hassecond ? 3 : 2;
-    Expr result = NewStatOrExpr(EXPR_RANGE, size * sizeof(Expr), 0);
+    Expr result = NewStatOrExpr(cs, EXPR_RANGE, size * sizeof(Expr), 0);
     WRITE_EXPR(
-        result, 0,
-        SyntaxTreeDefaultExprCoder(ElmRecST(EXPR_RANGE, node, "first")));
+        cs, result, 0,
+        SyntaxTreeDefaultExprCoder(cs, ElmRecST(EXPR_RANGE, node, "first")));
     WRITE_EXPR(
-        result, size - 1,
-        SyntaxTreeDefaultExprCoder(ElmRecST(EXPR_RANGE, node, "last")));
+        cs, result, size - 1,
+        SyntaxTreeDefaultExprCoder(cs, ElmRecST(EXPR_RANGE, node, "last")));
     if (hassecond) {
-        WRITE_EXPR(result, 1,
+        WRITE_EXPR(cs, result, 1,
                    SyntaxTreeDefaultExprCoder(
-                       ElmRecST(EXPR_RANGE, node, "second")));
+                       cs, ElmRecST(EXPR_RANGE, node, "second")));
     }
     return result;
 }
@@ -423,13 +456,13 @@ static Obj SyntaxTreeRecExpr(Obj result, Expr expr)
     return result;
 }
 
-static Expr SyntaxTreeCodeRecExpr(Obj node)
+static Expr SyntaxTreeCodeRecExpr(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeRecExpr", node);
     UInt1 tnum = GetTypeTNum(node);
     Obj   keyvalue = ElmRecST(tnum, node, "keyvalue");
     UInt  len = LEN_LIST(keyvalue);
-    Expr  record = NewStatOrExpr(tnum, 2 * len * sizeof(Expr), 0);
+    Expr  record = NewStatOrExpr(cs, tnum, 2 * len * sizeof(Expr), 0);
     for (int i = 0; i < len; i++) {
         Obj  keyvaluepair = ELM_LIST(keyvalue, i + 1);
         Obj  keynode = ElmRecST(tnum, keyvaluepair, "key");
@@ -439,11 +472,11 @@ static Expr SyntaxTreeCodeRecExpr(Obj node)
             key = INTEXPR_INT(RNamObj(keynode));
         }
         else {
-            key = SyntaxTreeDefaultExprCoder(keynode);
+            key = SyntaxTreeDefaultExprCoder(cs, keynode);
         }
-        Expr value = SyntaxTreeDefaultExprCoder(valuenode);
-        WRITE_EXPR(record, 2 * i, key);
-        WRITE_EXPR(record, 2 * i + 1, value);
+        Expr value = SyntaxTreeDefaultExprCoder(cs, valuenode);
+        WRITE_EXPR(cs, record, 2 * i, key);
+        WRITE_EXPR(cs, record, 2 * i + 1, value);
     }
     return record;
 }
@@ -466,23 +499,23 @@ static Obj SyntaxTreeFloatEager(Obj result, Expr expr)
     return result;
 }
 
-static Expr SyntaxTreeCodeFloatLazy(Obj node)
+static Expr SyntaxTreeCodeFloatLazy(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeFloatLazy", node);
     Obj value = ElmRecST(EXPR_FLOAT_LAZY, node, "value");
-    return CodeLazyFloatExpr(value, 0);
+    return CodeLazyFloatExpr(cs, value, 0);
 }
 
-static Expr SyntaxTreeCodeFloatEager(Obj node)
+static Expr SyntaxTreeCodeFloatEager(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeFloatEager", node);
     Obj  value = ElmRecST(EXPR_FLOAT_EAGER, node, "value");
     Obj  string = ElmRecST(EXPR_FLOAT_EAGER, node, "string");
     Obj  mark = ElmRecST(EXPR_FLOAT_EAGER, node, "mark");
-    Expr fl = NewStatOrExpr(EXPR_FLOAT_EAGER, 3 * sizeof(UInt), 0);
-    WRITE_EXPR(fl, 0, AddValueToBody(value));
-    WRITE_EXPR(fl, 1, AddValueToBody(string));
-    WRITE_EXPR(fl, 2, (UInt)CHAR_VALUE(mark));
+    Expr fl = NewStatOrExpr(cs, EXPR_FLOAT_EAGER, 3 * sizeof(UInt), 0);
+    WRITE_EXPR(cs, fl, 0, AddValueToBody(cs, value));
+    WRITE_EXPR(cs, fl, 1, AddValueToBody(cs, string));
+    WRITE_EXPR(cs, fl, 2, (UInt)CHAR_VALUE(mark));
     return fl;
 }
 
@@ -520,26 +553,26 @@ static Obj SyntaxTreeCompilePragma(Obj result, Stat stat)
     return result;
 }
 
-static Expr SyntaxTreeCodeIf(Obj node)
+static Expr SyntaxTreeCodeIf(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeIf", node);
     UInt1 tnum = GetTypeTNum(node);
     Obj   branches = ElmRecST(tnum, node, "branches");
     UInt  len = LEN_LIST(branches);
-    Expr  ifexpr = NewStatOrExpr(tnum, 2 * len * sizeof(Expr), 0);
+    Expr  ifexpr = NewStatOrExpr(cs, tnum, 2 * len * sizeof(Expr), 0);
     for (int i = 0; i < len; i++) {
         Obj  condbodypair = ELM_LIST(branches, i + 1);
         Obj  conditionnode = ElmRecST(tnum, condbodypair, "condition");
         Obj  bodynode = ElmRecST(tnum, condbodypair, "body");
-        Expr condition = SyntaxTreeDefaultExprCoder(conditionnode);
-        Stat body = SyntaxTreeDefaultStatCoder(bodynode);
-        WRITE_EXPR(ifexpr, 2 * i, condition);
-        WRITE_EXPR(ifexpr, 2 * i + 1, body);
+        Expr condition = SyntaxTreeDefaultExprCoder(cs, conditionnode);
+        Stat body = SyntaxTreeDefaultStatCoder(cs, bodynode);
+        WRITE_EXPR(cs, ifexpr, 2 * i, condition);
+        WRITE_EXPR(cs, ifexpr, 2 * i + 1, body);
     }
     return ifexpr;
 }
 
-static Expr SyntaxTreeCodeImmediateInteger(Obj node)
+static Expr SyntaxTreeCodeImmediateInteger(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeImmediateInteger", node);
     Obj value = ElmRecST(EXPR_INT, node, "value");
@@ -548,24 +581,24 @@ static Expr SyntaxTreeCodeImmediateInteger(Obj node)
     return INTEXPR_INT(INT_INTOBJ(value));
 }
 
-static Expr SyntaxTreeCodeValue(Obj node)
+static Expr SyntaxTreeCodeValue(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeValue", node);
     UInt1 tnum = GetTypeTNum(node);
     Obj   value = ElmRecST(tnum, node, "value");
-    Expr  expr = NewStatOrExpr(tnum, sizeof(UInt), 0);
-    Int   ix = AddValueToBody(value);
-    WRITE_EXPR(expr, 0, ix);
+    Expr  expr = NewStatOrExpr(cs, tnum, sizeof(UInt), 0);
+    Int   ix = AddValueToBody(cs, value);
+    WRITE_EXPR(cs, expr, 0, ix);
     return expr;
 }
 
-static Expr SyntaxTreeCodeChar(Obj node)
+static Expr SyntaxTreeCodeChar(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeChar", node);
     Obj  chr = ElmRecST(EXPR_CHAR, node, "value");
     Char currchar = CHAR_VALUE(chr);
-    Expr lit = NewStatOrExpr(EXPR_CHAR, sizeof(UChar), 0);
-    WRITE_EXPR(lit, 0, currchar);
+    Expr lit = NewStatOrExpr(cs, EXPR_CHAR, sizeof(UInt), 0);
+    WRITE_EXPR(cs, lit, 0, currchar);
     return lit;
 }
 
@@ -593,10 +626,10 @@ static Obj SyntaxTreeFunc(Obj result, Obj func)
     nloc = NLOC_FUNC(func);
     AssPRec(result, RNamName("nloc"), INTOBJ_INT(nloc));
 
-    /* names of arguments and locals*/
+    // names of arguments and locals
     AssPRec(result, RNamName("nams"), NAMS_FUNC(func));
 
-    /* switch to this function (so that 'READ_STAT' and 'READ_EXPR' work) */
+    // switch to this function (so that 'READ_STAT' and 'READ_EXPR' work)
     oldFrame = SWITCH_TO_NEW_LVARS(func, narg, nloc);
     stats = SyntaxTreeCompiler(OFFSET_FIRST_STAT);
     SWITCH_TO_OLD_LVARS(oldFrame);
@@ -606,7 +639,7 @@ static Obj SyntaxTreeFunc(Obj result, Obj func)
     return result;
 }
 
-static Expr SyntaxTreeCodeFunc(Obj node)
+static Expr SyntaxTreeCodeFunc(CodeState * cs, Obj node)
 {
     RequirePlainRec("SyntaxTreeCodeFunc", node);
     Int narg = INT_INTOBJ(ElmRecST(EXPR_FUNC, node, "narg"));
@@ -616,23 +649,25 @@ static Expr SyntaxTreeCodeFunc(Obj node)
     if (variadic == True) {
         narg = -narg;
     }
-    CodeFuncExprBegin(narg, nloc, nams, 0, 0);
+    CodeFuncExprBegin(cs, narg, nloc, nams, 0, 0);
     Obj  stat_rec = ElmRecST(EXPR_FUNC, node, "stats");
     Obj  body_stats = ElmRecST(EXPR_FUNC, stat_rec, "statements");
     UInt nr_stats = LEN_LIST(body_stats);
     for (int i = 1; i <= nr_stats; i++) {
-        Expr current = SyntaxTreeDefaultStatCoder(ELM_LIST(body_stats, i));
+        Expr current =
+            SyntaxTreeDefaultStatCoder(cs, ELM_LIST(body_stats, i));
         PushStat(current);
     }
-    return CodeFuncExprEnd(nr_stats, FALSE, 0);
+    return CodeFuncExprEnd(cs, nr_stats, FALSE, 0);
 }
 
 static Obj FuncSYNTAX_TREE_CODE(Obj self, Obj tree)
 {
     RequirePlainRec(SELF_NAME, tree);
-    CodeBegin();
-    SyntaxTreeCodeFunc(tree);
-    Obj func = CodeEnd(0);
+    CodeState cs;
+    CodeBegin(&cs);
+    SyntaxTreeCodeFunc(&cs, tree);
+    Obj func = CodeEnd(&cs, 0);
     if (IsbPRec(tree, RNamName("name"))) {
         Obj name = ELM_REC(tree, RNamName("name"));
         SET_NAME_FUNC(func, name);
@@ -713,14 +748,16 @@ static const CompilerT Compilers[] = {
     COMPILER_(STAT_RETURN_VOID),
 
     COMPILER_(STAT_ASS_LVAR,
-              ARG_EXPR("lvar", ObjInt_UInt, UInt_ObjInt),
+              ARG_EXPR("lvar", ObjInt_UInt, SyntaxTreeCodeObjInt),
               ARG_EXPR_("rhs")),
-    COMPILER_(STAT_UNB_LVAR, ARG_EXPR("lvar", ObjInt_UInt, UInt_ObjInt)),
+    COMPILER_(STAT_UNB_LVAR,
+              ARG_EXPR("lvar", ObjInt_UInt, SyntaxTreeCodeObjInt)),
 
     COMPILER_(STAT_ASS_HVAR,
-              ARG_EXPR("hvar", ObjInt_UInt, UInt_ObjInt),
+              ARG_EXPR("hvar", ObjInt_UInt, SyntaxTreeCodeObjInt),
               ARG_EXPR_("rhs")),
-    COMPILER_(STAT_UNB_HVAR, ARG_EXPR("hvar", ObjInt_UInt, UInt_ObjInt)),
+    COMPILER_(STAT_UNB_HVAR,
+              ARG_EXPR("hvar", ObjInt_UInt, SyntaxTreeCodeObjInt)),
 
     COMPILER_(STAT_ASS_GVAR,
               ARG_EXPR("gvar", NameGVar, SyntaxTreeCodeGVar),
@@ -729,25 +766,30 @@ static const CompilerT Compilers[] = {
 
     COMPILER_(
         STAT_ASS_LIST, ARG_EXPR_("list"), ARG_EXPR_("pos"), ARG_EXPR_("rhs")),
-    COMPILER_(
-        STAT_ASS_MAT, ARG_EXPR_("list"), ARG_EXPR_("row"), ARG_EXPR_("col"), ARG_EXPR_("rhs")),
-    COMPILER_(
-        STAT_ASSS_LIST, ARG_EXPR_("list"), ARG_EXPR_("poss"), ARG_EXPR_("rhss")),
+    COMPILER_(STAT_ASS_MAT,
+              ARG_EXPR_("list"),
+              ARG_EXPR_("row"),
+              ARG_EXPR_("col"),
+              ARG_EXPR_("rhs")),
+    COMPILER_(STAT_ASSS_LIST,
+              ARG_EXPR_("list"),
+              ARG_EXPR_("poss"),
+              ARG_EXPR_("rhss")),
     COMPILER_(STAT_ASS_LIST_LEV,
               ARG_EXPR_("lists"),
               ARG_EXPR_("pos"),
               ARG_EXPR_("rhss"),
-              ARG_EXPR("level", ObjInt_UInt, UInt_ObjInt)),
+              ARG_EXPR("level", ObjInt_UInt, SyntaxTreeCodeObjInt)),
     COMPILER_(STAT_ASSS_LIST_LEV,
               ARG_EXPR_("lists"),
               ARG_EXPR_("poss"),
               ARG_EXPR_("rhss"),
-              ARG_EXPR("level", ObjInt_UInt, UInt_ObjInt)),
+              ARG_EXPR("level", ObjInt_UInt, SyntaxTreeCodeObjInt)),
     COMPILER_(STAT_UNB_LIST, ARG_EXPR_("list"), ARG_EXPR_("pos")),
 
     COMPILER_(STAT_ASS_REC_NAME,
               ARG_EXPR_("record"),
-              ARG_EXPR("rnam", SyntaxTreeRNam, RNamObj),
+              ARG_EXPR("rnam", SyntaxTreeRNam, SyntaxTreeCodeRNamObj),
               ARG_EXPR_("rhs")),
     COMPILER_(STAT_ASS_REC_EXPR,
               ARG_EXPR_("record"),
@@ -755,8 +797,9 @@ static const CompilerT Compilers[] = {
               ARG_EXPR_("rhs")),
     COMPILER_(STAT_UNB_REC_NAME,
               ARG_EXPR_("record"),
-              ARG_EXPR("rnam", SyntaxTreeRNam, RNamObj)),
-    COMPILER_(STAT_UNB_REC_EXPR, ARG_EXPR_("record"), ARG_EXPR_("expression")),
+              ARG_EXPR("rnam", SyntaxTreeRNam, SyntaxTreeCodeRNamObj)),
+    COMPILER_(
+        STAT_UNB_REC_EXPR, ARG_EXPR_("record"), ARG_EXPR_("expression")),
 
     COMPILER_(STAT_ASS_POSOBJ,
               ARG_EXPR_("posobj"),
@@ -766,7 +809,7 @@ static const CompilerT Compilers[] = {
 
     COMPILER_(STAT_ASS_COMOBJ_NAME,
               ARG_EXPR_("comobj"),
-              ARG_EXPR("rnam", SyntaxTreeRNam, RNamObj),
+              ARG_EXPR("rnam", SyntaxTreeRNam, SyntaxTreeCodeRNamObj),
               ARG_EXPR_("rhs")),
     COMPILER_(STAT_ASS_COMOBJ_EXPR,
               ARG_EXPR_("comobj"),
@@ -774,11 +817,12 @@ static const CompilerT Compilers[] = {
               ARG_EXPR_("rhs")),
     COMPILER_(STAT_UNB_COMOBJ_NAME,
               ARG_EXPR_("comobj"),
-              ARG_EXPR("rnam", SyntaxTreeRNam, RNamObj)),
+              ARG_EXPR("rnam", SyntaxTreeRNam, SyntaxTreeCodeRNamObj)),
     COMPILER_(
         STAT_UNB_COMOBJ_EXPR, ARG_EXPR_("comobj"), ARG_EXPR_("expression")),
 
-    COMPILER_(STAT_INFO, ARG_EXPR_("sel"), ARG_EXPR_("lev"), ARGS_EXPR("args")),
+    COMPILER_(
+        STAT_INFO, ARG_EXPR_("sel"), ARG_EXPR_("lev"), ARGS_EXPR("args")),
     COMPILER_(STAT_ASSERT_2ARGS, ARG_EXPR_("level"), ARG_EXPR_("condition")),
     COMPILER_(STAT_ASSERT_3ARGS,
               ARG_EXPR_("level"),
@@ -787,7 +831,7 @@ static const CompilerT Compilers[] = {
     COMPILER(STAT_PRAGMA, SyntaxTreeCompilePragma, SyntaxTreeCodeValue),
 
 
-    /* Statements */
+    // Statements
     COMPILER_(EXPR_FUNCCALL_0ARGS, ARG_EXPR_("funcref"), ARGS_EXPR("args")),
     COMPILER_(EXPR_FUNCCALL_1ARGS, ARG_EXPR_("funcref"), ARGS_EXPR("args")),
     COMPILER_(EXPR_FUNCCALL_2ARGS, ARG_EXPR_("funcref"), ARGS_EXPR("args")),
@@ -834,7 +878,7 @@ static const CompilerT Compilers[] = {
     COMPILER(EXPR_RANGE, SyntaxTreeRangeExpr, SyntaxTreeCodeRangeExpr),
     COMPILER(EXPR_STRING, SyntaxTreeEvalCompiler, SyntaxTreeCodeValue),
     COMPILER(EXPR_REC, SyntaxTreeRecExpr, SyntaxTreeCodeRecExpr),
-    COMPILER_(EXPR_REC_TILDE),
+    COMPILER(EXPR_REC_TILDE, SyntaxTreeRecExpr, SyntaxTreeCodeRecExpr),
 
     COMPILER(
         EXPR_FLOAT_EAGER, SyntaxTreeFloatEager, SyntaxTreeCodeFloatEager),
@@ -844,10 +888,13 @@ static const CompilerT Compilers[] = {
     //           references to LVARs, so we have to treat
     //           them specially here
     COMPILER(EXPR_REF_LVAR, SyntaxTreeRefLVar, SyntaxTreeCodeRefLVar),
-    COMPILER_(EXPR_ISB_LVAR, ARG_EXPR("lvar", ObjInt_UInt, UInt_ObjInt)),
+    COMPILER_(EXPR_ISB_LVAR,
+              ARG_EXPR("lvar", ObjInt_UInt, SyntaxTreeCodeObjInt)),
 
-    COMPILER_(EXPR_REF_HVAR, ARG_EXPR("hvar", ObjInt_UInt, UInt_ObjInt)),
-    COMPILER_(EXPR_ISB_HVAR, ARG_EXPR("hvar", ObjInt_UInt, UInt_ObjInt)),
+    COMPILER_(EXPR_REF_HVAR,
+              ARG_EXPR("hvar", ObjInt_UInt, SyntaxTreeCodeObjInt)),
+    COMPILER_(EXPR_ISB_HVAR,
+              ARG_EXPR("hvar", ObjInt_UInt, SyntaxTreeCodeObjInt)),
 
     COMPILER_(EXPR_REF_GVAR, ARG_EXPR("gvar", NameGVar, SyntaxTreeCodeGVar)),
     COMPILER_(EXPR_ISB_GVAR, ARG_EXPR("gvar", NameGVar, SyntaxTreeCodeGVar)),
@@ -859,31 +906,33 @@ static const CompilerT Compilers[] = {
     COMPILER_(EXPR_ELMS_LIST, ARG_EXPR_("list"), ARG_EXPR_("poss")),
     COMPILER_(EXPR_ELM_LIST_LEV,
               ARG_EXPR_("lists"),
-              ARG_EXPR_("pos"),
-              ARG_EXPR_("level")),
+              ARGS_EXPR("pos"),
+              ARG_EXPR("level", ObjInt_UInt, SyntaxTreeCodeObjInt)),
     COMPILER_(EXPR_ELMS_LIST_LEV,
               ARG_EXPR_("lists"),
               ARG_EXPR_("poss"),
-              ARG_EXPR_("level")),
-    COMPILER_(EXPR_ISB_LIST, ARG_EXPR_("list"), ARG_EXPR_("pos")),
+              ARG_EXPR("level", ObjInt_UInt, SyntaxTreeCodeObjInt)),
+    COMPILER_(EXPR_ISB_LIST, ARG_EXPR_("list"), ARGS_EXPR("pos")),
     COMPILER_(EXPR_ELM_REC_NAME,
               ARG_EXPR_("record"),
-              ARG_EXPR("name", SyntaxTreeRNam, RNamObj)),
-    COMPILER_(EXPR_ELM_REC_EXPR, ARG_EXPR_("record"), ARG_EXPR_("expression")),
+              ARG_EXPR("name", SyntaxTreeRNam, SyntaxTreeCodeRNamObj)),
+    COMPILER_(
+        EXPR_ELM_REC_EXPR, ARG_EXPR_("record"), ARG_EXPR_("expression")),
     COMPILER_(EXPR_ISB_REC_NAME,
               ARG_EXPR_("record"),
-              ARG_EXPR("name", SyntaxTreeRNam, RNamObj)),
-    COMPILER_(EXPR_ISB_REC_EXPR, ARG_EXPR_("record"), ARG_EXPR_("expression")),
+              ARG_EXPR("name", SyntaxTreeRNam, SyntaxTreeCodeRNamObj)),
+    COMPILER_(
+        EXPR_ISB_REC_EXPR, ARG_EXPR_("record"), ARG_EXPR_("expression")),
     COMPILER_(EXPR_ELM_POSOBJ, ARG_EXPR_("posobj"), ARG_EXPR_("pos")),
     COMPILER_(EXPR_ISB_POSOBJ, ARG_EXPR_("posobj"), ARG_EXPR_("pos")),
     COMPILER_(EXPR_ELM_COMOBJ_NAME,
               ARG_EXPR_("comobj"),
-              ARG_EXPR("name", SyntaxTreeRNam, RNamObj)),
+              ARG_EXPR("name", SyntaxTreeRNam, SyntaxTreeCodeRNamObj)),
     COMPILER_(
         EXPR_ELM_COMOBJ_EXPR, ARG_EXPR_("comobj"), ARG_EXPR_("expression")),
     COMPILER_(EXPR_ISB_COMOBJ_NAME,
               ARG_EXPR_("comobj"),
-              ARG_EXPR("name", SyntaxTreeRNam, RNamObj)),
+              ARG_EXPR("name", SyntaxTreeRNam, SyntaxTreeCodeRNamObj)),
     COMPILER_(
         EXPR_ISB_COMOBJ_EXPR, ARG_EXPR_("comobj"), ARG_EXPR_("expression")),
 };
@@ -906,7 +955,7 @@ static StructGVarFunc GVarFuncs[] = { GVAR_FUNC_1ARGS(SYNTAX_TREE, func),
 
 static Int InitKernel(StructInitInfo * module)
 {
-    /* init filters and functions */
+    // init filters and functions
     InitHdlrFuncsFromTable(GVarFuncs);
 
     InitGlobalBag(&typeStrings, "typeStrings");
@@ -917,7 +966,7 @@ static Int InitKernel(StructInitInfo * module)
 
 static Int InitLibrary(StructInitInfo * module)
 {
-    /* init filters and functions */
+    // init filters and functions
     InitGVarFuncsFromTable(GVarFuncs);
 
     typeStrings = NEW_PLIST(T_PLIST, ARRAY_SIZE(Compilers));
