@@ -36,6 +36,10 @@ Int4 SyGAPCRC(const Char * name);
 */
 Obj SyGetOsRelease(void);
 
+// When true, ignore if any new input from stdin. This is used to stop HPC-GAP
+// from reading stdin while forked subprocesses are running.
+extern UInt FreezeStdin;
+
 /****************************************************************************
 **
 *F * * * * * * * * * * * * * * * window handler * * * * * * * * * * * * * * *
@@ -151,7 +155,7 @@ Int SyIsEndOfFile(Int fid);
 **
 **  'syStartraw' tries to put the file with the file  identifier  <fid>  into
 **  raw mode.  I.e.,  disabling  echo  and  any  buffering.  It also finds  a
-**  place to put the echoing  for  'syEchoch'.  If  'syStartraw'  succedes it
+**  place to put the echoing  for  'syEchoch'.  If  'syStartraw'  succeeds it
 **  returns 1, otherwise, e.g., if the <fid> is not a terminal, it returns 0.
 **
 **  'syStopraw' stops the raw mode for the file  <fid>  again,  switching  it
@@ -166,11 +170,11 @@ void syStopraw(Int fid);
 
 /****************************************************************************
 **
-*F  SyFgets( <line>, <lenght>, <fid> )  . . . . .  get a line from file <fid>
+*F  SyFgets( <line>, <length>, <fid> )  . . . . .  get a line from file <fid>
 **
 **  'SyFgets' is called to read a line from the file  with  identifier <fid>.
 **  'SyFgets' (like 'fgets') reads characters until either  <length>-1  chars
-**  have been read or until a <newline> or an  <eof> character is encoutered.
+**  have been read or until a <newline> or an  <eof> character is encountered.
 **  It retains the '\n' (unlike 'gets'), if any, and appends '\0' to  <line>.
 **  'SyFgets' returns <line> if any char has been read, otherwise '(char*)0'.
 **
@@ -202,7 +206,7 @@ void syStopraw(Int fid);
 **      <ctr>-P redisplay the last input line, another <ctr>-P will redisplay
 **              the line before that, etc.  If the cursor is not in the first
 **              column only the lines starting with the string to the left of
-**              the cursor are taken. The history is limitied to ~8000 chars.
+**              the cursor are taken. The history is limited to ~8000 chars.
 **      <ctr>-N Like <ctr>-P but goes the other way round through the history
 **      <esc>-< goes to the beginning of the history.
 **      <esc>-> goes to the end of the history.
@@ -332,20 +336,9 @@ void SySetErrorNo(void);
 
 /****************************************************************************
 **
-*F * * * * * * * * * * * * * file and execution * * * * * * * * * * * * * * *
+*F * * * * * * * * * * * * * * * * * file * * * * * * * * * * * * * * * * * *
 */
 
-/****************************************************************************
-**
-*F  SyExecuteProcess( <dir>, <prg>, <in>, <out>, <args> ) . . . . new process
-**
-**  Start  <prg> in  directory <dir>  with  standard input connected to <in>,
-**  standard  output  connected to <out>   and arguments.  No  path search is
-**  performed, the return  value of the process  is returned if the operation
-**  system supports such a concept.
-*/
-UInt SyExecuteProcess(Char * dir, Char * prg, Int in, Int out, Char * args[]);
-
 
 /****************************************************************************
 **
@@ -418,13 +411,19 @@ Int SyRmdir(const Char * name);
 
 /****************************************************************************
 **
-*F  SyIsDir( <name> )  . . . . . . . . . . . . .  test if something is a dir
+*F  SyFileType( <path> )
 **
-**  Returns 'F' for a regular file, 'L' for a symbolic link and 'D'
-**  for a real directory, 'C' for a character device, 'B' for a block
-**  device 'P' for a FIFO (named pipe) and 'S' for a socket.
+**  Return a character describing the filesystem object with the given path:
+**  - 'F' for a regular file
+**  - 'L' for a symbolic link
+**  - 'D' for a directory
+**  - 'C' for a character device
+**  - 'B' for a block device
+**  - 'P' for a FIFO (named pipe)
+**  - 'S' for a socket
+**  - `\0` if there was en error (e.g. invalid path, unknown type, etc.)
 */
-Obj SyIsDir(const Char * name);
+char SyFileType(const Char * path);
 
 
 /****************************************************************************
