@@ -66,25 +66,24 @@ UInt SyMsgsFlagBags;
 Int SyGasmanNumbers[2][9];
 
 void SyMsgsBags (
-    UInt                full,
-    UInt                phase,
-    Int                 nr )
+    UInt        full,
+    UInt        phase,
+    Int         nr )
 {
-    Char                cmd [3];        /* command string buffer           */
-    Char                str [32];       /* string buffer                   */
-    Char                ch;             /* leading character               */
-    UInt                i;              /* loop variable                   */
-    Int                 copynr;         /* copy of <nr>                    */
-    UInt                shifted;        /* non-zero if nr > 10^6 and so
-                                           has to be shifted down          */
-    static UInt         tstart = 0;
+    Char        cmd [3];  // command string buffer
+    Char        str [32]; // string buffer
+    Char        ch;       // leading character
+    UInt        i;        // loop variable
+    Int         copynr;   // copy of <nr>
+    UInt        shifted;  // non-zero if nr > 10^6 and so has to be shifted down
+    static UInt tstart = 0;
 
-    /* remember the numbers */
+    // remember the numbers
     if (phase > 0)
       {
         SyGasmanNumbers[full][phase] = nr;
-        
-        /* in a full GC clear the partial numbers */
+
+        // in a full GC clear the partial numbers
         if (full)
           SyGasmanNumbers[0][phase] = 0;
       }
@@ -93,14 +92,14 @@ void SyMsgsBags (
         SyGasmanNumbers[full][0]++;
         tstart = SyTime();
       }
-    if (phase == 6) 
+    if (phase == 6)
       {
         UInt x = SyTime() - tstart;
         SyGasmanNumbers[full][7] = x;
         SyGasmanNumbers[full][8] += x;
       }
 
-    /* convert <nr> into a string with leading blanks                      */
+    // convert <nr> into a string with leading blanks
     copynr = nr;
     ch = '0';  str[7] = '\0';
     shifted = (nr >= ((phase % 2) ? 10000000 : 1000000)) ? 1 : 0;
@@ -113,7 +112,7 @@ void SyMsgsBags (
         shifted++;
         nr /= 1024;
       }
-      
+
     for ( i = ((phase % 2) == 1 && shifted) ? 6 : 7 ;
           i != 0; i-- ) {
         if      ( 0 < nr ) { str[i-1] = '0' + ( nr) % 10;  ch = ' '; }
@@ -128,9 +127,9 @@ void SyMsgsBags (
     if ((phase % 2) == 1 && shifted == 2)
       str[6] = 'M';
 
-    
 
-    /* ordinary full garbage collection messages                           */
+
+    // ordinary full garbage collection messages
     if ( 1 <= SyMsgsFlagBags && full ) {
         if ( phase == 0 ) { SyFputs( "#G  FULL ", 3 );                     }
         if ( phase == 1 ) { SyFputs( str, 3 );  SyFputs( "/",         3 ); }
@@ -141,7 +140,7 @@ void SyMsgsBags (
         if ( phase == 6 ) { SyFputs( str, 3 );  SyFputs( shifted ? "mb free\n" : "kb free\n", 3 ); }
     }
 
-    /* ordinary partial garbage collection messages                        */
+    // ordinary partial garbage collection messages
     if ( 2 <= SyMsgsFlagBags && ! full ) {
         if ( phase == 0 ) { SyFputs( "#G  PART ", 3 );                     }
         if ( phase == 1 ) { SyFputs( str, 3 );  SyFputs( "/",         3 ); }
@@ -151,7 +150,7 @@ void SyMsgsBags (
         if ( phase == 5 ) { SyFputs( str, 3 );  SyFputs( "/",         3 ); }
         if ( phase == 6 ) { SyFputs( str, 3 );  SyFputs( shifted ? "mb free\n":"kb free\n", 3 ); }
     }
-    /* package (window) mode full garbage collection messages              */
+    // package (window) mode full garbage collection messages
     if ( phase != 0 ) {
       cmd[0] = '@';
       cmd[1] = ( full ? '0' : ' ' ) + phase;
@@ -180,7 +179,7 @@ void SyMsgsBags (
 **  the workspace beyond 'SyStorMax' or to reduce it below 'SyStorMin'.
 */
 
-static UInt pagesize = 4096;   /* Will be initialised if SyAllocPool > 0 */
+static UInt pagesize = 4096;   // Will be initialised if SyAllocPool > 0
 
 static inline UInt SyRoundUpToPagesize(UInt x)
 {
@@ -300,8 +299,8 @@ int SyTryToIncreasePool(void)
 #define GAP_MMAP_FLAGS MAP_PRIVATE|MAP_ANONYMOUS
 #endif
 
-static void *SyMMapStart = NULL;   /* Start of mmap'ed region for POOL */
-static void *SyMMapEnd;            /* End of mmap'ed region for POOL */
+static void *SyMMapStart = NULL;   // Start of mmap'ed region for POOL
+static void *SyMMapEnd;            // End of mmap'ed region for POOL
 static void *SyMMapAdvised;        /* We have already advised about non-usage
                                       up to here. */
 
@@ -309,7 +308,7 @@ void SyMAdviseFree(void)
 {
     size_t size;
     void *from;
-    if (!SyMMapStart) 
+    if (!SyMMapStart)
         return;
     from = EndOfWorkspace();
     from = (void *)SyRoundUpToPagesize((UInt) from);
@@ -345,11 +344,11 @@ void SyMAdviseFree(void)
 #if !defined(NO_DIRTY_OSX_MMAP_TRICK) && defined(__APPLE__)
     if (mmap(from, size, PROT_NONE,
             MAP_PRIVATE|MAP_ANONYMOUS|MAP_FIXED, -1, 0) != from) {
-        Panic("OS X trick to free pages did not work!");
+        Panic("macOS trick to free pages did not work!");
     }
     if (mmap(from, size, PROT_READ|PROT_WRITE,
             MAP_PRIVATE|MAP_ANONYMOUS|MAP_FIXED, -1, 0) != from) {
-        Panic("OS X trick to free pages did not work!!");
+        Panic("macOS trick to free pages did not work!!");
     }
 #endif
 }
@@ -359,7 +358,7 @@ static void * SyAnonMMap(size_t size)
     void *result;
     size = SyRoundUpToPagesize(size);
 #ifdef SYS_IS_64_BIT
-    /* The following is at 16 Terabyte: */
+    // The following is at 16 Terabyte:
     result = mmap((void *) (16L*1024*1024*1024*1024), size,
                   PROT_READ|PROT_WRITE, GAP_MMAP_FLAGS, -1, 0);
     if (result == MAP_FAILED) {
@@ -378,9 +377,9 @@ static void * SyAnonMMap(size_t size)
     return result;
 }
 
+// This tries to increase the pool size by a factor of 3/2, if this
+// worked, then 0 is returned, otherwise -1.
 static int SyTryToIncreasePool(void)
-/* This tries to increase the pool size by a factor of 3/2, if this
- * worked, then 0 is returned, otherwise -1. */
 {
     void *result;
     size_t size;
@@ -395,7 +394,7 @@ static int SyTryToIncreasePool(void)
         munmap(result,newchunk);
         return -1;
     }
-    /* We actually got an extension! */
+    // We actually got an extension!
     SyMMapEnd = (void *)((char *)SyMMapEnd + newchunk);
     SyAllocPool += newchunk;
     return 0;
@@ -405,12 +404,12 @@ static int SyTryToIncreasePool(void)
 
 void SyMAdviseFree(void)
 {
-    /* do nothing */
+    // do nothing
 }
 
 static int SyTryToIncreasePool(void)
 {
-    return -1;   /* Refuse */
+    return -1;   // Refuse
 }
 
 #endif // defined(GAP_MEM_CHECK)
@@ -423,18 +422,18 @@ static void SyInitialAllocPool(void)
    pagesize = sysconf(_SC_PAGESIZE);
 #endif
 #endif
-   /* Otherwise we take the default of 4k as pagesize. */
+   // Otherwise we take the default of 4k as pagesize.
 
    do {
-       /* Always round up to pagesize: */
+       // Always round up to pagesize:
        SyAllocPool = SyRoundUpToPagesize(SyAllocPool);
 #ifdef HAVE_MADVISE
-       POOL = SyAnonMMap(SyAllocPool+pagesize);   /* For alignment */
+       POOL = SyAnonMMap(SyAllocPool+pagesize);   // For alignment
 #else
-       POOL = calloc(SyAllocPool+pagesize,1);   /* For alignment */
+       POOL = calloc(SyAllocPool+pagesize,1);   // For alignment
 #endif
        if (POOL != NULL) {
-           /* fprintf(stderr,"Pool size is %lx.\n",SyAllocPool); */
+           // fprintf(stderr,"Pool size is %lx.\n",SyAllocPool);
            break;
        }
        SyAllocPool = SyAllocPool / 2;
@@ -442,11 +441,11 @@ static void SyInitialAllocPool(void)
        if (SyAllocPool < 16*1024*1024) {
            Panic("cannot allocate initial memory");
        }
-   } while (1);   /* Is left by break */
+   } while (1);   // Is left by break
 
-   /* ensure alignment of start address */
+   // ensure alignment of start address
    syWorkspace = (UInt***)(SyRoundUpToPagesize((UInt) POOL));
-   /* Now both syWorkspace and SyAllocPool are aligned to pagesize */
+   // Now both syWorkspace and SyAllocPool are aligned to pagesize
 }
 
 #define INVALID_PTR ((UInt***)-1)
@@ -480,7 +479,7 @@ static Int SyFreeBagsFromPool(Int size)
 }
 
 
-#if defined(HAVE_SBRK) && !defined(HAVE_VM_ALLOCATE) /* prefer `vm_allocate' over `sbrk' */
+#if defined(HAVE_SBRK) && !defined(HAVE_VM_ALLOCATE) // prefer `vm_allocate' over `sbrk'
 
 static UInt *** SyAllocBagHelper(Int size)
 {
@@ -500,7 +499,7 @@ static UInt *** SyAllocBags_(UInt size)
     GAP_ASSERT(SyAllocPool == 0);
     UInt *** ret = INVALID_PTR;
 
-    /* force alignment on first call                                       */
+    // force alignment on first call
     if (syWorkspace == 0) {
         UInt align = (UInt)sbrk(0) % sizeof(UInt);
         if (align != 0)
@@ -546,7 +545,7 @@ static UInt *** SyFreeBags_(UInt size)
     GAP_ASSERT(SyAllocPool == 0);
     UInt *** ret = INVALID_PTR;
 
-    /* force alignment on first call                                       */
+    // force alignment on first call
     if (syWorkspace == 0) {
         UInt align = (UInt)sbrk(0) % sizeof(UInt);
         if (align != 0)
@@ -583,7 +582,7 @@ static UInt *** SyFreeBags_(UInt size)
 **
 *f  SyAllocBags( <size>, <need> )
 **
-**  Under MACH virtual memory managment functions are used instead of 'sbrk'.
+**  Under MACH virtual memory management functions are used instead of 'sbrk'.
 */
 #ifdef HAVE_VM_ALLOCATE
 
@@ -594,12 +593,12 @@ static UInt *** SyAllocBags_(UInt size)
     GAP_ASSERT(SyAllocPool == 0);
     UInt *** ret = INVALID_PTR;
 
-    /* check that <size> is divisible by <vm_page_size>                    */
+    // check that <size> is divisible by <vm_page_size>
     if ( size*1024 % vm_page_size != 0 ) {
         Panic("memory block size is not a multiple of vm_page_size");
     }
 
-    /* allocate memory anywhere on first call                              */
+    // allocate memory anywhere on first call
     else if ( 0 < size && syBase == 0 ) {
         GAP_ASSERT(syWorksize == 0);
         if ( vm_allocate(mach_task_self(),&syBase,size*1024,TRUE) == KERN_SUCCESS ) {
@@ -607,7 +606,7 @@ static UInt *** SyAllocBags_(UInt size)
         }
     }
 
-    /* get more memory from system                                         */
+    // get more memory from system
     else {
         vm_address_t adr;
         adr = (vm_address_t)( (char*) syBase + syWorksize*1024 );
@@ -629,17 +628,17 @@ static UInt *** SyFreeBags_(UInt size)
     GAP_ASSERT(SyAllocPool == 0);
     UInt *** ret = INVALID_PTR;
 
-    /* check that <size> is divisible by <vm_page_size>                    */
+    // check that <size> is divisible by <vm_page_size>
     if ( size*1024 % vm_page_size != 0 ) {
         Panic("memory block size is not a multiple of vm_page_size");
     }
 
-    /* check that we don't try to shrink uninitialized memory                */
+    // check that we don't try to shrink uninitialized memory
     else if ( syBase == 0 ) {
         Panic("trying to shrink uninitialized vm memory");
     }
 
-    /* don't shrink memory but mark it as deactivated                      */
+    // don't shrink memory but mark it as deactivated
     else if (syWorksize >= size && syWorksize - size >= SyStorMin) {
         vm_address_t adr;
         adr = (vm_address_t)( (char*) syBase + (syWorksize-size)*1024 );
@@ -665,7 +664,7 @@ void * SyAllocBags(Int size, UInt need)
 
     void * ret = INVALID_PTR;
 
-    /* first check if we would get above SyStorKill, if yes exit! */
+    // first check if we would get above SyStorKill, if yes exit!
     if (SyStorKill != 0 && SyStorKill < syWorksize + size) {
         if (need) {
             Panic("will not extend workspace above -K limit!");
