@@ -51,8 +51,8 @@
 
 #include <sys/stat.h>
 
-#ifdef __MACH__
-// Workaround: TRUE / FALSE are also defined by the OS X Mach-O headers
+#if defined(__APPLE__) && defined(__MACH__)
+// Workaround: TRUE / FALSE are also defined by the macOS Mach-O headers
 #define ENUM_DYLD_BOOL
 #include <mach-o/dyld.h>
 #endif
@@ -275,113 +275,6 @@ void Panic_(const char * file, int line, const char * fmt, ...)
 }
 
 
-/****************************************************************************
-**
-*F * * * * * * * * * * finding location of executable * * * * * * * * * * * *
-*/
-
-/****************************************************************************
-** The function 'find_yourself' is based on code (C) 2015 Mark Whitis, under
-** the MIT License : https://stackoverflow.com/a/34271901/928031
-*/
-
-static void
-find_yourself(const char * argv0, char * result, size_t resultsize)
-{
-    GAP_ASSERT(resultsize >= GAP_PATH_MAX);
-
-    char tmpbuf[GAP_PATH_MAX];
-
-    // absolute path, like '/usr/bin/gap'
-    if (argv0[0] == '/') {
-        if (realpath(argv0, result) && !access(result, F_OK)) {
-            return;    // success
-        }
-    }
-    // relative path, like 'bin/gap.sh'
-    else if (strchr(argv0, '/')) {
-        if (!getcwd(tmpbuf, sizeof(tmpbuf)))
-            return;
-        gap_strlcat(tmpbuf, "/", sizeof(tmpbuf));
-        gap_strlcat(tmpbuf, argv0, sizeof(tmpbuf));
-        if (realpath(tmpbuf, result) && !access(result, F_OK)) {
-            return;    // success
-        }
-    }
-    // executable name, like 'gap'
-    else {
-        char pathenv[GAP_PATH_MAX], *saveptr, *pathitem;
-        gap_strlcpy(pathenv, getenv("PATH"), sizeof(pathenv));
-        pathitem = strtok_r(pathenv, ":", &saveptr);
-        for (; pathitem; pathitem = strtok_r(NULL, ":", &saveptr)) {
-            gap_strlcpy(tmpbuf, pathitem, sizeof(tmpbuf));
-            gap_strlcat(tmpbuf, "/", sizeof(tmpbuf));
-            gap_strlcat(tmpbuf, argv0, sizeof(tmpbuf));
-            if (realpath(tmpbuf, result) && !access(result, F_OK)) {
-                return;    // success
-            }
-        }
-    }
-
-    *result = 0;    // reset buffer after error
-}
-
-
-static char GAPExecLocation[GAP_PATH_MAX] = "";
-
-static void SetupGAPLocation(const char * argv0)
-{
-    // In the code below, we keep reseting locBuf, as some of the methods we
-    // try do not promise to leave the buffer empty on a failed return.
-    char locBuf[GAP_PATH_MAX] = "";
-    Int4 length = 0;
-
-#if defined(__APPLE__) && defined(__MACH__)
-    uint32_t len = sizeof(locBuf);
-    if (_NSGetExecutablePath(locBuf, &len) != 0) {
-        *locBuf = 0;    // reset buffer after error
-    }
-#endif
-
-    // try Linux procfs
-    if (!*locBuf) {
-        ssize_t ret = readlink("/proc/self/exe", locBuf, sizeof(locBuf));
-        if (ret < 0)
-            *locBuf = 0;    // reset buffer after error
-    }
-
-    // try FreeBSD / DragonFly BSD procfs
-    if (!*locBuf) {
-        ssize_t ret = readlink("/proc/curproc/file", locBuf, sizeof(locBuf));
-        if (ret < 0)
-            *locBuf = 0;    // reset buffer after error
-    }
-
-    // try NetBSD procfs
-    if (!*locBuf) {
-        ssize_t ret = readlink("/proc/curproc/exe", locBuf, sizeof(locBuf));
-        if (ret < 0)
-            *locBuf = 0;    // reset buffer after error
-    }
-
-    // if we are still failing, go and search the path
-    if (!*locBuf) {
-        find_yourself(argv0, locBuf, GAP_PATH_MAX);
-    }
-
-    // resolve symlinks (if present)
-    if (!realpath(locBuf, GAPExecLocation))
-        *GAPExecLocation = 0;    // reset buffer after error
-
-    // now strip the executable name off
-    length = strlen(GAPExecLocation);
-    while (length > 0 && GAPExecLocation[length] != '/') {
-        GAPExecLocation[length] = 0;
-        length--;
-    }
-}
-
-
 /****************************************************************************
 **
 *F  SyDotGapPath()
@@ -392,43 +285,6 @@ const Char * SyDotGapPath(void)
 }
 
 
-/****************************************************************************
-**
-*F  SySetInitialGapRootPaths( <string> )  . . . . .  set the root directories
-**
-**  Set up GAP's initial root paths, based on the location of the
-**  GAP executable.
-*/
-static void SySetInitialGapRootPaths(void)
-{
-    if (GAPExecLocation[0] != 0) {
-        // GAPExecLocation might be a subdirectory of GAP root,
-        // so we will go and search for the true GAP root.
-        // We try stepping back up to two levels.
-        char pathbuf[GAP_PATH_MAX];
-        char initgbuf[GAP_PATH_MAX];
-        strxcpy(pathbuf, GAPExecLocation, sizeof(pathbuf));
-        for (Int i = 0; i < 3; ++i) {
-            strxcpy(initgbuf, pathbuf, sizeof(initgbuf));
-            strxcat(initgbuf, "lib/init.g", sizeof(initgbuf));
-
-            if (SyIsReadableFile(initgbuf) == 0) {
-                SySetGapRootPath(pathbuf);
-                // escape from loop
-                return;
-            }
-            // try up a directory level
-            strxcat(pathbuf, "../", sizeof(pathbuf));
-        }
-    }
-
-    // Set GAP root path to current directory, if we have no other
-    // idea, and for backwards compatibility.
-    // Note that GAPExecLocation must always end with a slash.
-    SySetGapRootPath("./");
-}
-
-
 /****************************************************************************
 **
 *F  InitSystem( <argc>, <argv> )  . . . . . . . . . initialize system package
@@ -455,7 +311,7 @@ static sizeMultiplier memoryUnits[]= {
 #ifdef SYS_IS_64_BIT
   {'t', 1024UL*1024*1024*1024},
   {'T', 1024UL*1024*1024*1024},
-  {'p', 1024UL*1024*1024*1024*1024}, /* you never know */
+  {'p', 1024UL*1024*1024*1024*1024}, // you never know
   {'P', 1024UL*1024*1024*1024*1024},
 #endif
 };
@@ -626,51 +482,51 @@ static Int printVersion(Char ** argv, void * dummy)
 }
 
 
-/* These are just the options that need kernel processing. Additional options will be 
-   recognised and handled in the library */
-
-/* These options must be kept in sync with those in system.g, so the help output
-   is correct */
+// These are just the options that need kernel processing. Additional options
+// will be recognised and handled in the library
+//
+// These options must be kept in sync with those in system.g, so the help
+// output is correct
 static const struct optInfo options[] = {
-  { 'C',  "", processCompilerArgs, 0, 4}, /* must handle in kernel */
-  { 'D',  "debug-loading", toggle, &SyDebugLoading, 0}, /* must handle in kernel */
+  { 'C',  "", processCompilerArgs, 0, 4}, // must handle in kernel
+  { 'D',  "debug-loading", toggle, &SyDebugLoading, 0}, // must handle in kernel
 #if defined(USE_GASMAN) || defined(USE_BOEHM_GC)
-  { 'K',  "maximal-workspace", storeMemory2, &SyStorKill, 1}, /* could handle from library with new interface */
+  { 'K',  "maximal-workspace", storeMemory2, &SyStorKill, 1}, // could handle from library with new interface
 #endif
 #ifdef GAP_ENABLE_SAVELOAD
-  { 'L', "", storeString, &SyRestoring, 1}, /* must be handled in kernel  */
-  { 'R', "", unsetString, &SyRestoring, 0}, /* kernel */
+  { 'L', "", storeString, &SyRestoring, 1}, // must be handled in kernel
+  { 'R', "", unsetString, &SyRestoring, 0}, // kernel
 #endif
-  { 'M', "", toggle, &SyUseModule, 0}, /* must be handled in kernel */
-  { 'e', "", toggle, &SyCTRD, 0 }, /* kernel */
-  { 'f', "", forceLineEditing, (void *)2, 0 }, /* probably library now */
-  { 'E', "", toggle, &SyUseReadline, 0 }, /* kernel */
-  { 'l', "roots", setGapRootPath, 0, 1}, /* kernel */
+  { 'M', "", toggle, &SyUseModule, 0}, // must be handled in kernel
+  { 'e', "", toggle, &SyCTRD, 0 }, // kernel
+  { 'f', "", forceLineEditing, (void *)2, 0 }, // probably library now
+  { 'E', "", toggle, &SyUseReadline, 0 }, // kernel
+  { 'l', "roots", setGapRootPath, 0, 1}, // kernel
 #ifdef USE_GASMAN
-  { 'm', "", storeMemory2, &SyStorMin, 1 }, /* kernel */
+  { 'm', "", storeMemory2, &SyStorMin, 1 }, // kernel
 #endif
-  { 'r', "", toggle, &IgnoreGapRC, 0 }, /* kernel */
+  { 'r', "", toggle, &IgnoreGapRC, 0 }, // kernel
 #ifdef USE_GASMAN
-  { 's', "", storeMemory, &SyAllocPool, 1 }, /* kernel */
+  { 's', "", storeMemory, &SyAllocPool, 1 }, // kernel
 #endif
-  { 'n', "", forceLineEditing, 0, 0}, /* prob library */
+  { 'n', "", forceLineEditing, 0, 0}, // prob library
 #ifdef USE_GASMAN
-  { 'o', "", storeMemory2, &SyStorMax, 1 }, /* library with new interface */
+  { 'o', "", storeMemory2, &SyStorMax, 1 }, // library with new interface
 #endif
-  { 'p', "", toggle, &SyWindow, 0 }, /* ?? */
-  { 'q', "", toggle, &SyQuiet, 0 }, /* ?? */
+  { 'p', "", toggle, &SyWindow, 0 }, // ??
+  { 'q', "", toggle, &SyQuiet, 0 }, // ??
 #ifdef HPCGAP
-  { 'S', "", toggle, &ThreadUI, 0 }, /* Thread UI */
-  { 'Z', "", toggle, &DeadlockCheck, 0 }, /* Deadlock prevention */
-  { 'P', "", storePosInteger, &SyNumProcessors, 1 }, /* number of CPUs */
-  { 'G', "", storePosInteger, &SyNumGCThreads, 1 }, /* number of GC threads */
-  { 0  , "single-thread", toggle, &SingleThreadStartup, 0 }, /* startup with one thread only */
+  { 'S', "", toggle, &ThreadUI, 0 }, // Thread UI
+  { 'Z', "", toggle, &DeadlockCheck, 0 }, // Deadlock prevention
+  { 'P', "", storePosInteger, &SyNumProcessors, 1 }, // number of CPUs
+  { 'G', "", storePosInteger, &SyNumGCThreads, 1 }, // number of GC threads
+  { 0  , "single-thread", toggle, &SingleThreadStartup, 0 }, // startup with one thread only
 #endif
-  /* The following options must be handled in the kernel so they are set up before loading the library */
-  { 0  , "prof", enableProfilingAtStartup, 0, 1},    /* enable profiling at startup */
-  { 0  , "memprof", enableMemoryProfilingAtStartup, 0, 1 }, /* enable memory profiling at startup */
-  { 0  , "cover", enableCodeCoverageAtStartup, 0, 1}, /* enable code coverage at startup */
-  { 0  , "quitonbreak", toggle, &SyQuitOnBreak, 0}, /* Quit GAP if we enter the break loop */
+  // The following options must be handled in the kernel so they are set up before loading the library
+  { 0  , "prof", enableProfilingAtStartup, 0, 1},    // enable profiling at startup
+  { 0  , "memprof", enableMemoryProfilingAtStartup, 0, 1 }, // enable memory profiling at startup
+  { 0  , "cover", enableCodeCoverageAtStartup, 0, 1}, // enable code coverage at startup
+  { 0  , "quitonbreak", toggle, &SyQuitOnBreak, 0}, // Quit GAP if we enter the break loop
   { 0  , "enableMemCheck", enableMemCheck, 0, 0 },
   { 0  , "version", printVersion, 0, 0 },
   { 0, "", 0, 0, 0}};
@@ -679,18 +535,18 @@ static const struct optInfo options[] = {
 Char ** SyOriginalArgv;
 UInt SyOriginalArgc;
 
- 
+
 
 void InitSystem (
     Int                 argc,
     Char *              argv [],
     UInt                handleSignals )
 {
-    UInt                i;             /* loop variable                   */
-    Int res;                       /* return from option processing function */
+    UInt                i;             // loop variable
+    Int res;                       // return from option processing function
 
-    /* Initialize global and static variables */
-    SyCTRD = 1;             
+    // Initialize global and static variables
+    SyCTRD = 1;
     SyCompilePlease = 0;
     SyDebugLoading = 0;
     SyLineEdit = 1;
@@ -721,9 +577,9 @@ void InitSystem (
 #endif // defined(SYS_IS_64_BIT)
 
 #ifdef SYS_IS_64_BIT
-    SyAllocPool = 4096L*1024*1024;   /* Note this is in bytes! */
+    SyAllocPool = 4096L*1024*1024;   // Note this is in bytes!
 #else
-    SyAllocPool = 1536L*1024*1024;   /* Note this is in bytes! */
+    SyAllocPool = 1536L*1024*1024;   // Note this is in bytes!
 #endif // defined(SYS_IS_64_BIT)
     SyStorOverrun = SY_STOR_OVERRUN_CLEAR;
     SyStorKill = 0;
@@ -744,20 +600,13 @@ void InitSystem (
         SyInstallAnswerIntr();
     }
 
-#if defined(SYS_DEFAULT_PATHS)
-    SySetGapRootPath( SYS_DEFAULT_PATHS );
-#else
-    SetupGAPLocation(argv[0]);
-    SySetInitialGapRootPaths();
-#endif
-
-    /* save the original command line for export to GAP */
+    // save the original command line for export to GAP
     SyOriginalArgc = argc;
     SyOriginalArgv = argv;
 
-    /* scan the command line for options that we have to process in the kernel */
-    /* we just scan the whole command line looking for the keys for the options we recognise */
-    /* anything else will presumably be dealt with in the library */
+    // scan the command line for options that we have to process in the kernel
+    // we just scan the whole command line looking for the keys for the options we recognise
+    // anything else will presumably be dealt with in the library
     while ( argc > 1 )
       {
         if (argv[1][0] == '-' ) {
@@ -775,7 +624,7 @@ void InitSystem (
                        (options[i].shortkey != 0 || options[i].longkey[0] != 0); i++)
             ;
 
-        
+
 
 
           if (argc < 2 + options[i].minargs)
@@ -792,26 +641,26 @@ void InitSystem (
             }
           if (options[i].handler) {
             res = (*options[i].handler)(argv+2, options[i].otherArg);
-            
+
             switch (res)
               {
               case -1: goto usage;
-                /*            case -2: goto fullusage; */
-              default: ;     /* fall through and continue */
+                // case -2: goto fullusage;
+              default: ;     // fall through and continue
               }
           }
           else
             res = options[i].minargs;
-          /*    recordOption(argv[1][1], res,  argv+2); */
+          // recordOption(argv[1][1], res,  argv+2);
           argv += 1 + res;
           argc -= 1 + res;
-          
+
         }
         else {
           argv++;
           argc--;
         }
-          
+
       }
 #if !defined(HAVE_LIBREADLINE)
     // don't use readline of readline is not available (obviously)
@@ -822,36 +671,38 @@ void InitSystem (
     if (SyWindow)
         SyUseReadline = 0;
     // don't use readline if stdin is not attached to a terminal
-    else if (!isatty(fileno(stdin)))
-        SyUseReadline = 0;
+    // FIXME: disabled this, as it breaks certain workspaces (see also
+    // issue https://github.com/gap-system/gap/issues/5014)
+    //else if (!isatty(fileno(stdin)))
+    //    SyUseReadline = 0;
 #endif
 
     InitSysFiles();
 
-    /* now that the user has had a chance to give -x and -y,
-       we determine the size of the screen ourselves */
+    // now that the user has had a chance to give -x and -y,
+    // we determine the size of the screen ourselves
     getwindowsize();
 
 #ifdef USE_GASMAN
-    /* fix max if it is lower than min                                     */
+    // fix max if it is lower than min
     if ( SyStorMax != 0 && SyStorMax < SyStorMin ) {
         SyStorMax = SyStorMin;
     }
 
-    /* fix pool size if larger than SyStorKill */
+    // fix pool size if larger than SyStorKill
     if ( SyStorKill != 0 && SyAllocPool != 0 &&
                             SyAllocPool > 1024 * SyStorKill ) {
         SyAllocPool = SyStorKill * 1024;
     }
 #endif
 
-    /* when running in package mode set ctrl-d and line editing            */
+    // when running in package mode set ctrl-d and line editing
     if ( SyWindow ) {
         SyRedirectStderrToStdOut();
         syWinPut( 0, "@p", "1." );
     }
 
-    /* should GAP load 'init/lib.g' on initialization */
+    // should GAP load 'init/lib.g' on initialization
     if ( SyCompilePlease ) {
         SyLoadSystemInitFile = 0;
     }
@@ -861,12 +712,12 @@ void InitSystem (
     }
 #endif
 
-    /* the users home directory                                            */
+    // the users home directory
     if ( getenv("HOME") != 0 ) {
         strxcpy(DotGapPath, getenv("HOME"), sizeof(DotGapPath));
 # if defined(__APPLE__)
-        /* On Mac OS, add .gap to the sys roots, but leave */
-        /* DotGapPath at $HOME/Library/Preferences/GAP     */
+        // On Mac OS, add .gap to the sys roots, but leave
+        // DotGapPath at $HOME/Library/Preferences/GAP
         strxcat(DotGapPath, "/.gap;", sizeof(DotGapPath));
         if (!IgnoreGapRC) {
           SySetGapRootPath(DotGapPath);
@@ -887,10 +738,10 @@ void InitSystem (
     }
 
 
-    /* now we start                                                        */
+    // now we start
     return;
 
-    /* print a usage message                                               */
+    // print a usage message
 usage:
  fputs("usage: gap [OPTIONS] [FILES]\n", stderr);
  fputs("       run the Groups, Algorithms and Programming system, Version ", stderr);
