@@ -12,7 +12,7 @@
 #ifndef GAP_VECFFE_H
 #define GAP_VECFFE_H
 
-#include "system.h"
+#include "common.h"
 
 /****************************************************************************
 **
